@@ -1,4 +1,9 @@
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -17,17 +22,45 @@
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
+#	include "ClientList.h"
 #	include "DownloadQueue.h"
-#	include "updownclient.h"
 #	include "PartFile.h"
+#	include "SearchList.h"
+#	include "SysTray.h"
+#	include "TransferWnd.h"
+#	include "updownclient.h"
+#	include "xmuleDlg.h"
 #endif
 
 #include <wx/filename.h>
 #include <wx/listimpl.cpp>
 #include <wx/file.h>
+#include <wx/textfile.h>
 #include <wx/utils.h>
 
-CDownloadQueue::CDownloadQueue(CPreferences* in_prefs,CSharedFileList* in_sharedfilelist){
+#define		MAX_FILES_PER_UDP_PACKET	31
+#define		MAX_REQUESTS_PER_SERVER		35
+
+int CDownloadQueue::GetMaxFilesPerUDPServerPacket() const {
+	//from emule30e
+	int iMaxFilesPerPacket;
+	if (cur_udpserver&& cur_udpserver->GetUDPFlags()& SRV_UDPFLG_EXT_GETSOURCES) {
+		// get max. file ids per packet
+		if (m_cRequestsSentToServer < MAX_REQUESTS_PER_SERVER) {
+			if(MAX_FILES_PER_UDP_PACKET<MAX_REQUESTS_PER_SERVER- m_cRequestsSentToServer)
+			iMaxFilesPerPacket = MAX_FILES_PER_UDP_PACKET;
+			else
+				iMaxFilesPerPacket = MAX_REQUESTS_PER_SERVER- m_cRequestsSentToServer;
+		} else {
+			iMaxFilesPerPacket = 0;
+		}
+	}
+	else
+	iMaxFilesPerPacket = 1;
+	return iMaxFilesPerPacket;
+}
+
+CDownloadQueue::CDownloadQueue(CPreferences* in_prefs,CSharedFileList* in_sharedfilelist) {
 	app_prefs = in_prefs;
 	sharedfilelist = in_sharedfilelist;
 	filesrdy = 0;
@@ -37,6 +70,7 @@ CDownloadQueue::CDownloadQueue(CPreferences* in_prefs,CSharedFileList* in_shared
 	lastudpsearchtime = 0;
 	lastudpstattime = 0;
 	udcounter = 0;
+	m_cRequestsSentToServer = 0;
 	m_nDownDataRateMSOverhead = 0;
 	m_nDownDatarateOverhead = 0;
 	m_nDownDataOverheadSourceExchange = 0;
@@ -52,16 +86,15 @@ CDownloadQueue::CDownloadQueue(CPreferences* in_prefs,CSharedFileList* in_shared
 }
 
 void CDownloadQueue::UpdateDisplayedInfo(bool force) {
-    DWORD curTick = ::GetTickCount();
-
-    if(force || curTick-m_lastRefreshedDLDisplay > MINWAIT_BEFORE_DLDISPLAY_WINDOWUPDATE+(uint32)(rand()/(RAND_MAX/1000))) {
-        theApp.xmuledlg->transferwnd->downloadlistctrl->UpdateItem(this);
-        m_lastRefreshedDLDisplay = curTick;
-    }
+	DWORD curTick = ::GetTickCount();
+	if(force|| curTick-m_lastRefreshedDLDisplay > MINWAIT_BEFORE_DLDISPLAY_WINDOWUPDATE+(uint32) (rand() /(RAND_MAX/1000))) {
+		theApp.xmuledlg->transferwnd->downloadlistctrl->UpdateItem(this);
+		m_lastRefreshedDLDisplay = curTick;
+	}
 }
 
-void CDownloadQueue::AddPartFilesToShare(){
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+void CDownloadQueue::AddPartFilesToShare() {
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		CPartFile* cur_file = filelist.GetAt(pos);
 		if (cur_file->GetStatus(true) == PS_READY) {
 			sharedfilelist->SafeAddKFile(cur_file,true);
@@ -70,59 +103,59 @@ void CDownloadQueue::AddPartFilesToShare(){
 	}
 }
 
-void CDownloadQueue::CompDownDatarateOverhead(){
+void CDownloadQueue::CompDownDatarateOverhead() {
 	m_AvarageDDRO_list.AddTail(m_nDownDataRateMSOverhead);
-	if (m_AvarageDDRO_list.GetCount() > 150)
+	if (m_AvarageDDRO_list.GetCount() > 150) {
 		m_AvarageDDRO_list.RemoveAt(m_AvarageDDRO_list.GetHeadPosition());
-	
+	}
 	m_nDownDatarateOverhead = 0;
 	m_nDownDataRateMSOverhead = 0;
 	for (POSITION pos = m_AvarageDDRO_list.GetHeadPosition();pos != 0;m_AvarageDDRO_list.GetNext(pos))
-		m_nDownDatarateOverhead += m_AvarageDDRO_list.GetAt(pos);
-
-	if(m_AvarageDDRO_list.GetCount() > 10)
+	m_nDownDatarateOverhead+= m_AvarageDDRO_list.GetAt(pos);
+	if(m_AvarageDDRO_list.GetCount() > 10) {
 		m_nDownDatarateOverhead = 10*m_nDownDatarateOverhead/m_AvarageDDRO_list.GetCount();
-	else
+	} else {
 		m_nDownDatarateOverhead = 0;
+	}
 	return;
 }
 
-void CDownloadQueue::Init(){
+void CDownloadQueue::Init() {
 	// find all part files, read & hash them if needed and store into a list
 	//CFileFind ff;
 	int count = 0;
-
 	//char* searchpath = new char[strlen(app_prefs->GetTempDir())+MAX_PATH];
 	wxString searchPath(app_prefs->GetTempDir());
-	searchPath += "/*.part.met";
+	searchPath+= "/*.part.met";
 	//sprintf(searchpath,"%s\\*.part.met",app_prefs->GetTempDir());
 	//delete[] searchpath;
-
 	//check all part.met files
 	//bool end = !ff.FindFile(searchPath, 0);
 	printf("Loading temp files from %s.\n",searchPath.GetData());
 	wxString fileName=::wxFindFirstFile(searchPath,wxFILE);
 	//while (!end){
 	while(!fileName.IsEmpty()) {
-	  //end = !ff.FindNextFile();
-	  //if (ff.IsDirectory())
-	  //	continue;
-	  wxFileName myFileName(fileName);
-	  
-	  printf("Loading %s... ",myFileName.GetFullName().GetData());
-	  CPartFile* toadd = new CPartFile();
-	  if (toadd->LoadPartFile(app_prefs->GetTempDir(),(char*)myFileName.GetFullName().GetData())){
-	    count++;
-	    printf("Done.\n");
-	    filelist.AddTail(toadd);			// to downloadqueue
-	    if (toadd->GetStatus(true) == PS_READY)
-	      sharedfilelist->SafeAddKFile(toadd); // part files are always shared files
-	    //  printf("status = %d\n",toadd->GetStatus(true));
-	    theApp.xmuledlg->transferwnd->downloadlistctrl->AddFile(toadd);// show in downloadwindow
-	  }
-	  else
-	    delete toadd;
-	  fileName=::wxFindNextFile();
+		//end = !ff.FindNextFile();
+		//if (ff.IsDirectory())
+		//	continue;
+		wxFileName myFileName(fileName);
+		printf("Loading %s... ",myFileName.GetFullName() .GetData());
+		CPartFile* toadd = new CPartFile();
+		if (toadd->LoadPartFile(app_prefs->GetTempDir(),(char*) myFileName.GetFullName() .GetData())) {
+			count++;
+			printf("Done.\n");
+			// to downloadqueue:
+			filelist.AddTail(toadd);
+			if (toadd->GetStatus(true) == PS_READY)
+			// part files are always shared files:
+			sharedfilelist->SafeAddKFile(toadd);
+			//  printf("status = %d\n",toadd->GetStatus(true));
+			// show in downloadwindow:
+			theApp.xmuledlg->transferwnd->downloadlistctrl->AddFile(toadd);
+		} else {
+			delete toadd;
+		}
+		fileName=::wxFindNextFile();
 	}
 	//ff.Close();
 	if(count == 0) {
@@ -133,69 +166,69 @@ void CDownloadQueue::Init(){
 	}
 }
 
-CDownloadQueue::~CDownloadQueue(){
-//	if (!theApp.xmuledlg->m_app_state== APP_STATE_SHUTINGDOWN )
-//		SavePartFiles(true);	// changed by InterCeptor
-
-	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+CDownloadQueue::~CDownloadQueue() {
+	//	if (!theApp.xmuledlg->m_app_state== APP_STATE_SHUTINGDOWN )
+	//		SavePartFiles(true);	// changed by InterCeptor
+	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		//filelist.GetAt(pos)->m_hpartfile.Flush() ; // Flush before close app [Tarod]
 		//filelist.GetAt(pos)->SavePartFile();
 		delete filelist.GetAt(pos);
 	}
-
 }
 
 // [InterCeptor]
-void CDownloadQueue::SavePartFiles(bool del /*= false*/) {
-	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos))
-	{
+    void CDownloadQueue::SavePartFiles(bool del /*= false*/
 
+
+
+
+) {
+	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		filelist.GetAt(pos)->m_hpartfile.Flush();
 		filelist.GetAt(pos)->SavePartFile();
 		if (del)
-			delete filelist.GetAt(pos);
+		delete filelist.GetAt(pos);
 	}
 }
 
-void CDownloadQueue::AddSearchToDownload(CSearchFile* toadd){
+void CDownloadQueue::AddSearchToDownload(CSearchFile* toadd) {
 	if (IsFileExisting(toadd->GetFileHash()))
-		return;
+	return;
 	CPartFile* newfile = new CPartFile(toadd);
 	if (!newfile) return;
-	if (newfile->GetStatus() == PS_ERROR){
+	if (newfile->GetStatus() == PS_ERROR) {
 		delete newfile;
 		return;
 	}
 	AddDownload(newfile);
 }
 
-void CDownloadQueue::AddSearchToDownload(CString link){
-// Bodo: Why here not, but in
-// Bodo: void CDownloadQueue::AddSearchToDownload(CSearchFile* toadd)?
-//	if (IsFileExisting("link->GetFileHash()"))
-//		return;
+void CDownloadQueue::AddSearchToDownload(CString link) {
+	// Bodo: Why here not, but in
+	// Bodo: void CDownloadQueue::AddSearchToDownload(CSearchFile* toadd)?
+	//	if (IsFileExisting("link->GetFileHash()"))
+	//		return;
 	CPartFile* newfile = new CPartFile(link);
 	if (!newfile) return;
-	if (newfile->GetStatus() == PS_ERROR){
+	if (newfile->GetStatus() == PS_ERROR) {
 		delete newfile;
 		return;
 	}
 	AddDownload(newfile);
 }
 
-void CDownloadQueue::StartNextFile(){
-	if( !theApp.glob_prefs->StartNextFile() )
-		return;
-	CPartFile*  pfile = NULL;
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+void CDownloadQueue::StartNextFile() {
+	if(!theApp.glob_prefs->StartNextFile())
+	return;
+	CPartFile* pfile = NULL;
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		CPartFile* cur_file = filelist.GetAt(pos);
-		if (cur_file->GetStatus() == PS_PAUSED){
-			if (!pfile){
+		if (cur_file->GetStatus() == PS_PAUSED) {
+			if (!pfile) {
 				pfile = cur_file;
 				if (pfile->GetDownPriority() == PR_HIGH) break;
-			}
-			else{
-				if (cur_file->GetDownPriority() > pfile->GetDownPriority()){
+			} else {
+				if (cur_file->GetDownPriority() > pfile->GetDownPriority()) {
 					pfile = cur_file;
 					if (pfile->GetDownPriority() == PR_HIGH) break;
 				}
@@ -208,7 +241,7 @@ void CDownloadQueue::StartNextFile(){
 void CDownloadQueue::AddFileLinkToDownload(CED2KFileLink* pLink) {
 	CPartFile* newfile = new CPartFile(pLink);
 	if (!newfile) return;
-	if (newfile->GetStatus() == PS_ERROR){
+	if (newfile->GetStatus() == PS_ERROR) {
 		delete newfile;
 		newfile=NULL;
 		// Bodo: no return?
@@ -216,11 +249,12 @@ void CDownloadQueue::AddFileLinkToDownload(CED2KFileLink* pLink) {
 		AddDownload(newfile);
 	}
 	if (pLink->HasValidSources()) {
-		if (newfile) { // Bodo: "no return?" seems to be ok...
+		if (newfile) {
+			// Bodo: "no return?" seems to be ok...
 			newfile->AddClientSources(pLink->SourcesList,1);
 		} else {
-				CPartFile* partfile = GetFileByID((uchar*)pLink->GetHashKey());
-				if (partfile) partfile->AddClientSources(pLink->SourcesList,1);
+			CPartFile* partfile = GetFileByID((uchar*) pLink->GetHashKey());
+			if (partfile) partfile->AddClientSources(pLink->SourcesList,1);
 		}
 	}
 }
@@ -228,8 +262,7 @@ void CDownloadQueue::AddFileLinkToDownload(CED2KFileLink* pLink) {
 void CDownloadQueue::AddDownload(CPartFile* newfile) {
 	// Barry - Add in paused mode if required
 	if (theApp.glob_prefs->AddNewFilesPaused())
-		newfile->PauseFile();
-
+	newfile->PauseFile();
 	filelist.AddTail(newfile);
 	SortByPriority();
 	theApp.xmuledlg->transferwnd->downloadlistctrl->AddFile(newfile);
@@ -239,134 +272,131 @@ void CDownloadQueue::AddDownload(CPartFile* newfile) {
 	theApp.xmuledlg->ShowNotifier(msgTemp, TBN_DLOAD);
 }
 
-bool CDownloadQueue::IsFileExisting(uchar* fileid){
-	if (CKnownFile* file = sharedfilelist->GetFileByID((uchar*)fileid)){
+bool CDownloadQueue::IsFileExisting(uchar* fileid) {
+	if (CKnownFile* file = sharedfilelist->GetFileByID((uchar*) fileid)) {
 		if (file->IsPartFile())
-			theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADING), file->GetFileName() );
+		theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADING), file->GetFileName());
 		else
-			theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADED), file->GetFileName() );
+			theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADED), file->GetFileName());
 		return true;
-	}
-	else if ( file = this->GetFileByID((uchar*)fileid)){
-		theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADING), file->GetFileName() );
+	} else if (file = this->GetFileByID((uchar*) fileid)) {
+		theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_ALREADY_DOWNLOADING), file->GetFileName());
 		return true;
 	}
 	return false;
 }
 
 
-void CDownloadQueue::Process(){
+void CDownloadQueue::Process() {
 	uint32 downspeed = 0;
-	if (app_prefs->GetMaxDownload() != UNLIMITED && datarate > 1500){
-		downspeed = (app_prefs->GetMaxDownload()*1024*100)/(datarate+1); //(uint16)((float)((float)(app_prefs->GetMaxDownload()*1024)/(datarate+1)) * 100);
+	if (app_prefs->GetMaxDownload() != UNLIMITED&& datarate > 1500) {
+		//(uint16)((float)((float)(app_prefs->GetMaxDownload()*1024)/(datarate+1)) * 100);:
+		downspeed = (app_prefs->GetMaxDownload() *1024*100) /(datarate+1);
 		if (downspeed < 50)
-			downspeed = 50;
+		downspeed = 50;
 		else if (downspeed > 200)
 			downspeed = 200;
 		//if (app_prefs->GetMaxDownload()*1024 < datarate)
 		//	downspeed = 0xFFF;
 	}
 	datarate = 0;
-	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
-		CPartFile* cur_file =  filelist.GetAt(pos);
-		if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (!cur_file->IsAutoDownPriority() && cur_file->GetDownPriority() == PR_HIGH)){
-			datarate += cur_file->Process(downspeed);
+	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
+		CPartFile* cur_file = filelist.GetAt(pos);
+		if ((cur_file->GetStatus() == PS_READY|| cur_file->GetStatus() == PS_EMPTY)&& (!cur_file->IsAutoDownPriority()&& cur_file->GetDownPriority() == PR_HIGH)) {
+			datarate+= cur_file->Process(downspeed);
 		}
 	}
-	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
-		CPartFile* cur_file =  filelist.GetAt(pos);
-		if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (!cur_file->IsAutoDownPriority() && cur_file->GetDownPriority() == PR_NORMAL)){
-			datarate += cur_file->Process(downspeed);
+	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
+		CPartFile* cur_file = filelist.GetAt(pos);
+		if ((cur_file->GetStatus() == PS_READY|| cur_file->GetStatus() == PS_EMPTY)&& (!cur_file->IsAutoDownPriority()&& cur_file->GetDownPriority() == PR_NORMAL)) {
+			datarate+= cur_file->Process(downspeed);
 		}
 	}
-	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
-		CPartFile* cur_file =  filelist.GetAt(pos);
-		if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (cur_file->GetDownPriority() == PR_LOW || cur_file->IsAutoDownPriority())){
-			datarate += cur_file->Process(downspeed);
+	for (POSITION pos =filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
+		CPartFile* cur_file = filelist.GetAt(pos);
+		if ((cur_file->GetStatus() == PS_READY|| cur_file->GetStatus() == PS_EMPTY)&& (cur_file->GetDownPriority() == PR_LOW|| cur_file->IsAutoDownPriority())) {
+			datarate+= cur_file->Process(downspeed);
 		}
 	}
 	udcounter++;
-	if (udcounter == 5){
-		if((!lastudpstattime) || (::GetTickCount() - lastudpstattime) > UDPSERVERSTATTIME){
+	if (udcounter == 5) {
+		if((!lastudpstattime)|| (::GetTickCount()- lastudpstattime) > UDPSERVERSTATTIME) {
 			lastudpstattime = ::GetTickCount();
 			theApp.serverlist->ServerStats();
 		}
 	}
-	if (udcounter == 10){
+	if (udcounter == 10) {
 		udcounter = 0;
-		if ((!lastudpsearchtime) || (::GetTickCount() - lastudpsearchtime) > UDPSERVERREASKTIME)
-			SendNextUDPPacket();
+		if ((!lastudpsearchtime)|| (::GetTickCount()- lastudpsearchtime) > UDPSERVERREASKTIME)
+		SendNextUDPPacket();
 	}
-
 	// Check for new links once per second.
-	if ((::GetTickCount() - m_nLastED2KLinkCheck) >= 1000) {
+	if ((::GetTickCount()- m_nLastED2KLinkCheck) >= 1000) {
 		wxString filename = filename.Format("%s/.xMule/ED2KLinks", getenv("HOME"));
 		if (wxFile::Exists(filename)) {
 			AddLinksFromFile();
 		}
 		m_nLastED2KLinkCheck = ::GetTickCount();
 	}
-
 }
 
-CPartFile* CDownloadQueue::GetFileByID(uchar* filehash){
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+CPartFile* CDownloadQueue::GetFileByID(uchar* filehash) {
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		if (!memcmp(filehash,filelist.GetAt(pos)->GetFileHash(),16))
-			return filelist.GetAt(pos);
+		return filelist.GetAt(pos);
 	}
 	return 0;
 }
 
-CPartFile* CDownloadQueue::GetFileByIndex(int index){
-//      if (index>=filelist.GetCount()) return 0;
+CPartFile* CDownloadQueue::GetFileByIndex(int index) {
+	//      if (index>=filelist.GetCount()) return 0;
 	int count=0;
-
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		if (count==index) return filelist.GetAt(pos);
 		count++;
 	}
 	return 0;
 }
 
-bool CDownloadQueue::IsPartFile(void* totest){
+bool CDownloadQueue::IsPartFile(void* totest) {
 	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos))
-		if (totest == filelist.GetAt(pos))
-			return true;
+	if (totest == filelist.GetAt(pos))
+	return true;
 	return false;
 }
 
-void CDownloadQueue::CheckAndAddSource(CPartFile* sender,CUpDownClient* source){
+void CDownloadQueue::CheckAndAddSource(CPartFile* sender,CUpDownClient* source) {
 	// if we block loopbacks at this point it should prevent us from connecting to ourself
 	// Bodo: If one has running two clients running on the same system,
 	// Bodo: does this prevent us from conneting to the other client?
-	if(!source->HasLowID() && (source->GetUserID() & 0xFF) == 0x7F) {
+	if(!source->HasLowID()&& (source->GetUserID()& 0xFF) == 0x7F) {
 		delete source;
 		return;
 	}
-/*
-	if (IsBlacklisted(source)) {
-		delete source;
-		return;
-	}
-*/
+ /*
+ if (IsBlacklisted(source)) {
+ delete source;
+ return;
+ }
+    */
 	// uses this only for temp. clients
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		CPartFile* cur_file = filelist.GetAt(pos);
 		for (int sl=0;sl<SOURCESSLOTS;sl++) if (!cur_file->srclists[sl].IsEmpty())
-		for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition();pos2 != 0; cur_file->srclists[sl].GetNext(pos2)){
-			if (cur_file->srclists[sl].GetAt(pos2)->Compare(source)){
-				if (cur_file == sender){ // this file has already this source
+		for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition();pos2 != 0; cur_file->srclists[sl].GetNext(pos2)) {
+			if (cur_file->srclists[sl].GetAt(pos2)->Compare(source)) {
+				if (cur_file == sender) {
+					// this file has already this source
 					delete source;
 					return;
 				}
 				// set request for this source
-				if (cur_file->srclists[sl].GetAt(pos2)->AddRequestForAnotherFile(sender)){
+				if (cur_file->srclists[sl].GetAt(pos2)->AddRequestForAnotherFile(sender)) {
 					// add it to uploadlistctrl
 					theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender,cur_file->srclists[sl].GetAt(pos2),true);
 					delete source;
 					return;
-				}
-				else{
+				} else {
 					delete source;
 					return;
 				}
@@ -377,29 +407,27 @@ void CDownloadQueue::CheckAndAddSource(CPartFile* sender,CUpDownClient* source){
 	//if yes the known client will be attached to the var "source"
 	//and the old sourceclient will be deleted
 	if (theApp.clientlist->AttachToAlreadyKnown(&source,0))
-		source->SetDownloadFile(sender);
+	source->SetDownloadFile(sender);
 	else
-		theApp.clientlist->AddClient(source,true);
-
+	theApp.clientlist->AddClient(source,true);
 	sender->srclists[source->sourcesslot].AddTail(source);
 	theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender,source,false);
 	//theApp.xmuledlg->transferwnd.downloadlistctrl.UpdateItem(this);
 	UpdateDisplayedInfo();
 }
 
-void CDownloadQueue::CheckAndAddKnownSource(CPartFile* sender,CUpDownClient* source){
-	if(!source->HasLowID() && (source->GetUserID() & 0xFF) == 0x7F)
-		return;
-
+void CDownloadQueue::CheckAndAddKnownSource(CPartFile* sender,CUpDownClient* source) {
+	if(!source->HasLowID()&& (source->GetUserID()& 0xFF) == 0x7F)
+	return;
 	// use this for client which are already know (downloading for example)
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		CPartFile* cur_file = filelist.GetAt(pos);
 		for (int sl=0;sl<SOURCESSLOTS;sl++) if (!cur_file->srclists[sl].IsEmpty())
-		if (cur_file->srclists[sl].Find(source)){
+		if (cur_file->srclists[sl].Find(source)) {
 			if (cur_file == sender)
-				return;
+			return;
 			if (source->AddRequestForAnotherFile(sender))
-				theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender,source,true);
+			theApp.xmuledlg->transferwnd->downloadlistctrl->AddSource(sender,source,true);
 			return;
 		}
 	}
@@ -409,20 +437,20 @@ void CDownloadQueue::CheckAndAddKnownSource(CPartFile* sender,CUpDownClient* sou
 	UpdateDisplayedInfo();
 }
 
-bool CDownloadQueue::RemoveSource(CUpDownClient* toremove, bool	updatewindow){
+bool CDownloadQueue::RemoveSource(CUpDownClient* toremove, bool updatewindow) {
 	bool removed = false;
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		CPartFile* cur_file = filelist.GetAt(pos);
 		for (int sl=0;sl<SOURCESSLOTS;sl++) if (!cur_file->srclists[sl].IsEmpty())
-		for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition();pos2 != 0; cur_file->srclists[sl].GetNext(pos2)){
-			if (toremove == cur_file->srclists[sl].GetAt(pos2)){
+		for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition();pos2 != 0; cur_file->srclists[sl].GetNext(pos2)) {
+			if (toremove == cur_file->srclists[sl].GetAt(pos2)) {
 				cur_file->srclists[sl].RemoveAt(pos2);
 				cur_file->NewSrcPartsInfo();
 				removed = true;
-				/* Razor 1a - Modif by MikaelB */
-				if(!toremove->m_OtherRequests_list.IsEmpty())  {
+    /* Razor 1a - Modif by MikaelB */
+				if(!toremove->m_OtherRequests_list.IsEmpty()) {
 					POSITION pos3, pos4;
-					for(pos3=toremove->m_OtherRequests_list.GetHeadPosition();(pos4=pos3)!=NULL;) {
+					for(pos3=toremove->m_OtherRequests_list.GetHeadPosition();(pos4=pos3) !=NULL;) {
 						toremove->m_OtherRequests_list.GetNext(pos3);
 						POSITION pos5 = toremove->m_OtherRequests_list.GetAt(pos4)->A4AFSourcesList.Find(toremove);
 						if(pos5) {
@@ -438,13 +466,13 @@ bool CDownloadQueue::RemoveSource(CUpDownClient* toremove, bool	updatewindow){
 					theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(toremove, cur_file);
 				}
 				toremove->SetDownloadFile(NULL);
-				/* End modif */
+    /* End modif */
 				break;
 			}
 		}
 		cur_file->UpdateAvailablePartsCount();
 	}
-	if (updatewindow){
+	if (updatewindow) {
 		toremove->SetDownloadState(DS_NONE);
 		theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(toremove,0);
 	}
@@ -452,121 +480,180 @@ bool CDownloadQueue::RemoveSource(CUpDownClient* toremove, bool	updatewindow){
 	return removed;
 }
 
-void CDownloadQueue::RemoveFile(CPartFile* toremove){
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
-		if (toremove == filelist.GetAt(pos)){
+void CDownloadQueue::RemoveFile(CPartFile* toremove) {
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
+		if (toremove == filelist.GetAt(pos)) {
 			filelist.RemoveAt(pos);
 			return;
 		}
 	}
 }
 
-void CDownloadQueue::DeleteAll(){
+void CDownloadQueue::DeleteAll() {
 	POSITION pos;
-	for (pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+	for (pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		CPartFile* cur_file = filelist.GetAt(pos);
 		for (int sl=0;sl<SOURCESSLOTS;sl++) if (!cur_file->srclists[sl].IsEmpty())
-			cur_file->srclists[sl].RemoveAll();
+		cur_file->srclists[sl].RemoveAll();
 		// Barry - Should also remove all requested blocks
-		// Don't worry about deleting the blocks, that gets handled 
+		// Don't worry about deleting the blocks, that gets handled
 		// when CUpDownClient is deleted in CClientList::DeleteAll()
 		cur_file->RemoveAllRequestedBlocks();
 	}
 }
 
-bool CDownloadQueue::SendNextUDPPacket(){
-	if (filelist.IsEmpty() || !theApp.serverconnect->IsConnected())
-		return false;
-	if (!cur_udpserver)
-		if (!(cur_udpserver = theApp.serverlist->GetNextServer(cur_udpserver))){
-			StopUDPRequests();
-		};
+bool CDownloadQueue::SendGlobGetSourcesUDPPacket(CSafeMemFile& data) {
+	//from emule30e
+	bool bSentPacket = false;
+	if (cur_udpserver&& (theApp.serverconnect->GetCurrentServer() == NULL||
+	cur_udpserver != theApp.serverlist->GetServerByAddress(theApp.serverconnect->GetCurrentServer()->GetAddress(),
+	theApp.serverconnect->GetCurrentServer()->GetPort()))) {
+		int iFileIDs = data.GetLength() / 16;
+		Packet *packet=new Packet(&data);
+		packet->opcode = OP_GLOBGETSOURCES;
+		theApp.serverconnect->SendUDPPacket(packet,cur_udpserver,true);
+		m_cRequestsSentToServer+= iFileIDs;
+		bSentPacket = true;
+	}
+	return bSentPacket;
+}
 
-	// get nextfile
-	CPartFile* nextfile = 0;
-	while (!(nextfile && (nextfile->GetStatus() == PS_READY ||nextfile->GetStatus() == PS_EMPTY))){
-		if (lastfile == 0){
-			nextfile = filelist.GetHead();
-			lastfile = nextfile;
+
+bool CDownloadQueue::SendNextUDPPacket() {
+	//from emule30e & amule
+	if (filelist.IsEmpty()|| !theApp.serverconnect->IsConnected()) {
+		return false;
+	}
+	if (!cur_udpserver) {
+		if (!(cur_udpserver = theApp.serverlist->GetNextServer(cur_udpserver))) {
+			StopUDPRequests();
 		}
-		else{
-			POSITION pos = filelist.Find(lastfile);
-			if (!pos){
+		m_cRequestsSentToServer = 0;
+	}
+	int iMaxFilesPerPacket = GetMaxFilesPerUDPServerPacket();
+	bool bSentPacket = false;
+	CSafeMemFile dataGlobGetSources(16);
+	int iFiles = 0;
+	while (iFiles < iMaxFilesPerPacket&& !bSentPacket) {
+		// get next file to search sources for
+		CPartFile* nextfile = NULL;
+		while (!bSentPacket&& !(nextfile&& (nextfile->GetStatus() == PS_READY|| nextfile->GetStatus() == PS_EMPTY))) {
+			if (lastfile == NULL) {
+				// we just started the global source searching
+				// or have switched the server
+				// get first file to search sources for
 				nextfile = filelist.GetHead();
 				lastfile = nextfile;
-			}
-			else{
-				filelist.GetNext(pos);
-				if (pos == 0){
-					cur_udpserver = theApp.serverlist->GetNextServer(cur_udpserver);
-					if (cur_udpserver == 0){
-						lastudpsearchtime = ::GetTickCount();
-						lastfile = 0;
-						return false; // finished (processed all file & all servers)
-					}
+			} else {
+				POSITION pos = filelist.Find(lastfile);
+				if (pos == 0) {
+					// the last file is no longer in the DL-list
+					// (may have been finished or canceld)
+					// get first file to search sources for
 					nextfile = filelist.GetHead();
 					lastfile = nextfile;
-				}
-				else{
-					nextfile = filelist.GetAt(pos);
-					lastfile = nextfile;
+				} else {
+					filelist.GetNext(pos);
+					if (pos == 0) {
+						if (dataGlobGetSources.GetLength() > 0) {
+							if (SendGlobGetSourcesUDPPacket(dataGlobGetSources)) {
+								bSentPacket = true;
+							}
+							dataGlobGetSources.SetLength(0);
+						}
+						cur_udpserver = theApp.serverlist->GetNextServer(cur_udpserver);
+						m_cRequestsSentToServer = 0;
+						if (cur_udpserver == NULL) {
+							// finished asking all servers for all files
+							lastudpsearchtime = ::GetTickCount();
+							lastfile = NULL;
+							m_iSearchedServers = 0;
+							return false;
+						}
+						m_iSearchedServers++;
+						if (bSentPacket) {
+							lastfile = NULL;
+							break;
+						}
+						iMaxFilesPerPacket = GetMaxFilesPerUDPServerPacket();
+						nextfile = filelist.GetHead();
+						lastfile = nextfile;
+					} else {
+						nextfile = filelist.GetAt(pos);
+						lastfile = nextfile;
+					}
 				}
 			}
 		}
+		if (!bSentPacket&& nextfile&& nextfile->GetSourceCount() < theApp.glob_prefs->GetMaxSourcePerFileUDP()) {
+			dataGlobGetSources.Write(nextfile->GetFileHash(),16);
+			iFiles++;
+		}
+	}
+	if (!bSentPacket&& dataGlobGetSources.GetLength() > 0) {
+		SendGlobGetSourcesUDPPacket(dataGlobGetSources);
+	}
+	if (m_cRequestsSentToServer >= MAX_REQUESTS_PER_SERVER) {
+		if (filelist.GetCount() >= MAX_REQUESTS_PER_SERVER) {
+			for (int i = 0; i != MAX_REQUESTS_PER_SERVER; i++) {
+				filelist.AddHead(filelist.RemoveTail());
+			}
+		}
+		cur_udpserver = theApp.serverlist->GetNextServer(cur_udpserver);
+		m_cRequestsSentToServer = 0;
+		if (cur_udpserver == NULL) {
+			lastudpsearchtime = ::GetTickCount();
+			lastfile = NULL;
+			// finished (processed all file & all servers):
+			return false;
+		}
+		m_iSearchedServers++;
+		lastfile = NULL;
 	}
-	if( (theApp.glob_prefs->GetMaxSourcePerFileUDP()) < nextfile->GetSourceCount()) //<<--
-		return true; 
-	Packet packet(OP_GLOBGETSOURCES,16);
-	memcpy(packet.pBuffer,nextfile->GetFileHash(),16);
-	if (cur_udpserver != theApp.serverlist->GetServerByAddress(theApp.serverconnect->GetCurrentServer()->GetAddress(),theApp.serverconnect->GetCurrentServer()->GetPort()))
-		theApp.serverconnect->SendUDPPacket(&packet,cur_udpserver,false);
 	return true;
 }
 
-void CDownloadQueue::StopUDPRequests(){
+void CDownloadQueue::StopUDPRequests() {
 	cur_udpserver = 0;
 	lastudpsearchtime = ::GetTickCount();
 	lastfile = 0;
 }
 
-void CDownloadQueue::SortByPriority(){
-   POSITION pos1, pos2;
-   uint16 i = 0;
-   for( pos1 = filelist.GetHeadPosition(); ( pos2 = pos1 ) != NULL; ){
-	   filelist.GetNext(pos1);
-	   CPartFile* cur_file = filelist.GetAt(pos2);
-	   if (cur_file->GetDownPriority() == PR_HIGH){
-		   filelist.AddHead(cur_file);
-		   filelist.RemoveAt(pos2);
-	   }
-	   else if (cur_file->GetDownPriority() == PR_LOW){
-		   filelist.AddTail(cur_file);
-		   filelist.RemoveAt(pos2);
-	   }
-	   i++;
-	   if (i == filelist.GetCount())
-		   break;
-   }
+void CDownloadQueue::SortByPriority() {
+	POSITION pos1, pos2;
+	uint16 i = 0;
+	for(pos1 = filelist.GetHeadPosition(); (pos2 = pos1) != NULL;) {
+		filelist.GetNext(pos1);
+		CPartFile* cur_file = filelist.GetAt(pos2);
+		if (cur_file->GetDownPriority() == PR_HIGH) {
+			filelist.AddHead(cur_file);
+			filelist.RemoveAt(pos2);
+		} else if (cur_file->GetDownPriority() == PR_LOW) {
+			filelist.AddTail(cur_file);
+			filelist.RemoveAt(pos2);
+		}
+		i++;
+		if (i == filelist.GetCount())
+		break;
+	}
 }
 
 void CDownloadQueue::GetDownloadStats(int results[]) {
-	
 	results[0]=0;
 	results[1]=0;
-
-	for (POSITION pos =theApp.downloadqueue->filelist.GetHeadPosition();pos != 0;theApp.downloadqueue->filelist.GetNext(pos)){
-		CPartFile* cur_file =  filelist.GetAt(pos);
+	for (POSITION pos =theApp.downloadqueue->filelist.GetHeadPosition();pos != 0;theApp.downloadqueue->filelist.GetNext(pos)) {
+		CPartFile* cur_file = filelist.GetAt(pos);
 		results[0]+=cur_file->GetSourceCount();
 		results[1]+=cur_file->GetTransferingSrcCount();
 	}
 }
 
-CUpDownClient* CDownloadQueue::GetDownloadClientByIP(uint32 dwIP){
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+CUpDownClient* CDownloadQueue::GetDownloadClientByIP(uint32 dwIP) {
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		CPartFile* cur_file = filelist.GetAt(pos);
 		for (int sl=0;sl<SOURCESSLOTS;sl++) if (!cur_file->srclists[sl].IsEmpty())
-		for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition();pos2 != 0; cur_file->srclists[sl].GetNext(pos2)){
-			if (dwIP == cur_file->srclists[sl].GetAt(pos2)->GetIP()){
+		for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition();pos2 != 0; cur_file->srclists[sl].GetNext(pos2)) {
+			if (dwIP == cur_file->srclists[sl].GetAt(pos2)->GetIP()) {
 				return cur_file->srclists[sl].GetAt(pos2);
 			}
 		}
@@ -574,12 +661,11 @@ CUpDownClient* CDownloadQueue::GetDownloadClientByIP(uint32 dwIP){
 	return NULL;
 }
 
-    
+
 void CDownloadQueue::AddLinksFromFile() {
-        wxString filename;
+	wxString filename;
 	wxString link;
 	wxTextFile linksfile(wxString::Format("%s/.xMule/ED2KLinks", getenv("HOME")));
-	
 	if (linksfile.Open()) {
 		link = linksfile.GetFirstLine();
 		// GetLineCount returns the actual number of lines in file, but line numbering
@@ -591,7 +677,7 @@ void CDownloadQueue::AddLinksFromFile() {
 			}
 			try {
 				CED2KLink* pLink=CED2KLink::CreateLinkFromUrl(link);
-				if(pLink->GetKind()==CED2KLink::kFile) {
+				if(pLink->GetKind() ==CED2KLink::kFile) {
 					// All seems ok, add it to download queue.
 					AddFileLinkToDownload(pLink->GetFileLink());
 				} else {
@@ -604,7 +690,7 @@ void CDownloadQueue::AddLinksFromFile() {
 				theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERR_LINKERROR),buffer);
 			}
 			// We must double-check here where are we, because GetNextLine moves reading head
-			// one line below, and we must make sure that line exists. Thus check if we are 
+			// one line below, and we must make sure that line exists. Thus check if we are
 			// at least one line away from end before trying to read next line.
 			if (i < linksfile.GetLineCount()-1) {
 				link = linksfile.GetNextLine();
@@ -618,11 +704,15 @@ void CDownloadQueue::AddLinksFromFile() {
 	wxRemoveFile(wxString::Format("%s/.xMule/ED2KLinks", getenv("HOME")));
 }
 
-/* Razor 1a - Modif by MikaelB
-   RemoveSourceFromPartFile function */
-   
-void CDownloadQueue::RemoveSourceFromPartFile(CPartFile* file, CUpDownClient* client, POSITION position)
-{
+ /* Razor 1a - Modif by MikaelB
+    RemoveSourceFromPartFile function */
+
+
+
+
+
+
+void CDownloadQueue::RemoveSourceFromPartFile(CPartFile* file, CUpDownClient* client, POSITION position) {
 	// Remove source at position in sources list of file
 	file->srclists[client->sourcesslot].RemoveAt(position);
 	// Update infos of file
@@ -653,7 +743,7 @@ void CDownloadQueue::RemoveSourceFromPartFile(CPartFile* file, CUpDownClient* cl
 				// Remove this position of the A4AF sources list of file at current position in client's other requests list
 				client->m_OtherRequests_list.GetAt(temp_position)->A4AFSourcesList.RemoveAt(position2);
 				// Remove current position from the download list window
-				theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(client, client->m_OtherRequests_list.GetAt(temp_position));  
+				theApp.xmuledlg->transferwnd->downloadlistctrl->RemoveSource(client, client->m_OtherRequests_list.GetAt(temp_position));
 				// Remove current position from client's other requests list
 				client->m_OtherRequests_list.RemoveAt(temp_position);
 			}
@@ -661,34 +751,47 @@ void CDownloadQueue::RemoveSourceFromPartFile(CPartFile* file, CUpDownClient* cl
 	}
 	// If client's upload status id none
 	if(client->GetUploadState() == US_NONE) {
-		// Disconnect client
 		client->Disconnected();
 	}
 }
 
-/* End modif */
+    /* End modif */
 
-/* Razor 1a - Modif by MikaelB
-   DisableAnyA4AFAuto function */
-   
-void CDownloadQueue::DisableAnyA4AFAuto(void)
-{
+
+
+
+
+
+ /* Razor 1a - Modif by MikaelB
+    DisableAnyA4AFAuto function */
+
+
+
+
+
+
+void CDownloadQueue::DisableAnyA4AFAuto(void) {
 	// For all position in filelist...
 	for(POSITION position = filelist.GetHeadPosition();position != NULL;filelist.GetNext(position)) {
 		// Get file at position in filelist
 		CPartFile* file = (CPartFile*) filelist.GetAt(position);
 		// If file has been found...
 		if(file != NULL)
-		// Disable A4AF Auto 
+		// Disable A4AF Auto
 		file->SetA4AFAuto(false);
 	}
 }
 
-/* End modif */
-void CDownloadQueue::ResetCatParts(int cat){
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+    /* End modif */
+
+
+
+
+
+void CDownloadQueue::ResetCatParts(int cat) {
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		CPartFile* cur_file = filelist.GetAt(pos);
-		if (cur_file->GetCategory()==cat) {
+		if (cur_file->GetCategory() ==cat) {
 			cur_file->SetCategory(0);
 		} else if (cur_file->GetCategory() > cat) {
 			cur_file->SetCategory(cur_file->GetCategory()-1);
@@ -696,15 +799,14 @@ void CDownloadQueue::ResetCatParts(int cat){
 	}
 }
 
-void CDownloadQueue::SetCatPrio(int cat, uint8 newprio){
-	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)){
+void CDownloadQueue::SetCatPrio(int cat, uint8 newprio) {
+	for (POSITION pos = filelist.GetHeadPosition();pos != 0;filelist.GetNext(pos)) {
 		CPartFile* cur_file = filelist.GetAt(pos);
-		if (cat==0 || cur_file->GetCategory()==cat) {
+		if (cat==0|| cur_file->GetCategory() ==cat) {
 			if (newprio==PR_AUTO) {
 				cur_file->SetAutoDownPriority(true);
 				cur_file->SetDownPriority(PR_HIGH);
-			}
-			else {
+			} else {
 				cur_file->SetAutoDownPriority(false);
 				cur_file->SetDownPriority(newprio);
 			}
@@ -712,7 +814,7 @@ void CDownloadQueue::SetCatPrio(int cat, uint8 newprio){
 	}
 }
 
-void CDownloadQueue::SetCatStatus(int cat, int newstatus){
+void CDownloadQueue::SetCatStatus(int cat, int newstatus) {
 	bool reset=false;
 	POSITION pos= filelist.GetHeadPosition();
 	while (pos != 0) {
@@ -720,23 +822,23 @@ void CDownloadQueue::SetCatStatus(int cat, int newstatus){
 		if (!cur_file) {
 			continue;
 		}
-		if (cat == cur_file->GetCategory() || cat == 0) {
+		if (cat == cur_file->GetCategory()|| cat == 0) {
 			switch (newstatus) {
-				case MP_CANCEL:
-					cur_file->DeleteFile();
-					reset=true;
-					break;
-				case MP_PAUSE:
-					cur_file->PauseFile();
-					break;
-				case MP_STOP:
-					cur_file->StopFile();
-					break;
-				case MP_RESUME: 
-					if (cur_file->GetStatus()==PS_PAUSED) {
-						cur_file->ResumeFile();
-					}
-					break;
+			case MP_CANCEL:
+				cur_file->DeleteFile();
+				reset=true;
+				break;
+			case MP_PAUSE:
+				cur_file->PauseFile();
+				break;
+			case MP_STOP:
+				cur_file->StopFile();
+				break;
+			case MP_RESUME:
+				if (cur_file->GetStatus() ==PS_PAUSED) {
+					cur_file->ResumeFile();
+				}
+				break;
 			}
 		}
 		filelist.GetNext(pos);
@@ -746,3 +848,7 @@ void CDownloadQueue::SetCatStatus(int cat, int newstatus){
 		}
 	}
 }
+
+
+
+
