@@ -1,4 +1,9 @@
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -86,6 +91,8 @@ public:
 	void	SetCatStatus(int cat, int newstatus);
 protected:
 	bool	SendNextUDPPacket();
+	int	GetMaxFilesPerUDPServerPacket() const;
+	bool	SendGlobGetSourcesUDPPacket(CSafeMemFile& data);
 private:
 	CTypedPtrList<CPtrList, CPartFile*> filelist;
 	CSharedFileList* sharedfilelist;
@@ -98,6 +105,8 @@ private:
 	uint32		lastudpstattime;
 	uint32		m_nLastED2KLinkCheck;
 	uint8		udcounter;
+	uint8		m_cRequestsSentToServer;
+	int		m_iSearchedServers;
 
 	uint32		m_nDownDatarateOverhead;
 	uint32		m_nDownDataRateMSOverhead;
