@@ -1,3 +1,22 @@
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
 // CPPgSourcesDropping implementation file
 
 #ifdef PRECOMP
@@ -33,39 +52,32 @@ IMPLEMENT_DYNAMIC_CLASS(CPPgSourcesDropping,wxPanel)
 
 
 CPPgSourcesDropping::CPPgSourcesDropping(wxWindow* parent)
-  : wxPanel(parent,CPPgSourcesDropping::IDD)
-{
+: wxPanel(parent,CPPgSourcesDropping::IDD) {
 	// Getting preferences dialog notebook
 	wxNotebook* book= (wxNotebook*) parent;
-
 	// Load Sources Dropping panel from xml resource
 	wxPanel* page1 = _panel = wxXmlResource::Get()->LoadPanel(this,"DLG_PPG_SOURCES_DROPPING");
 	// Add this panel into preferences dialog notebook
 	book->AddPage(this,_("Sources Dropping"));
-
 	// looks stupid? it is :)
-	SetSize(page1->GetSize().GetWidth(),page1->GetSize().GetHeight()+60);
-	page1->SetSize(GetSize());  
-
+	SetSize(page1->GetSize() .GetWidth(),page1->GetSize() .GetHeight()+60);
+	page1->SetSize(GetSize());
 }
 
-CPPgSourcesDropping::~CPPgSourcesDropping()
-{
+CPPgSourcesDropping::~CPPgSourcesDropping() {
 }
 
-void CPPgSourcesDropping::Localize(void)
-{
+void CPPgSourcesDropping::Localize(void) {
 }
 
-void CPPgSourcesDropping::LoadSettings(void)
-{
+void CPPgSourcesDropping::LoadSettings(void) {
 	if (app_prefs->prefs->DropNoNeededSources) {
 		CheckDlgButton(IDC_ENABLE_AUTO_NNS, true);
 	} else {
 		CheckDlgButton(IDC_ENABLE_AUTO_NNS, false);
 	}
 	if (app_prefs->prefs->SwapNoNeededSources) {
-	    GetDlgItem(IDC_AUTO_NNS_EXTENDED_RADIO, wxRadioBox)->SetSelection(0);
+		GetDlgItem(IDC_AUTO_NNS_EXTENDED_RADIO, wxRadioBox)->SetSelection(0);
 	} else {
 		GetDlgItem(IDC_AUTO_NNS_EXTENDED_RADIO, wxRadioBox)->SetSelection(1);
 	}
@@ -79,33 +91,27 @@ void CPPgSourcesDropping::LoadSettings(void)
 	} else {
 		CheckDlgButton(IDC_ENABLE_AUTO_HQRS, false);
 	}
-
 	CString strBuffer;
 	strBuffer.Format("%d", app_prefs->prefs->HighQueueRanking);
 	GetDlgItem(IDC_HQR_VALUE, wxTextCtrl)->SetValue(strBuffer);
-
 	strBuffer.Format("%d", app_prefs->prefs->AutoDropTimer);
 	GetDlgItem(IDC_AUTO_DROP_TIMER, wxTextCtrl)->SetValue(strBuffer);
-
 }
 
-void CPPgSourcesDropping::OnApply()
-{
+void CPPgSourcesDropping::OnApply() {
 	wxString buffer;
 	app_prefs->prefs->DropNoNeededSources = GetDlgItem(IDC_ENABLE_AUTO_NNS, wxCheckBox)->GetValue();
 	app_prefs->prefs->SwapNoNeededSources = (GetDlgItem(IDC_AUTO_NNS_EXTENDED_RADIO, wxRadioBox)->GetSelection() == 0);
 	app_prefs->prefs->DropFullQueueSources = GetDlgItem(IDC_ENABLE_AUTO_FQS, wxCheckBox)->GetValue();
 	app_prefs->prefs->DropHighQueueRankingSources = GetDlgItem(IDC_ENABLE_AUTO_HQRS, wxCheckBox)->GetValue();
-
 	CString strBuffer;
-	/* Get the Queue Ranking from dialog. */
+    /* Get the Queue Ranking from dialog. */
 	strBuffer.Format("%d", app_prefs->prefs->HighQueueRanking);
 	if (GetDlgItem(IDC_HQR_VALUE, wxTextCtrl)->GetValue()) {
 		buffer = GetDlgItem(IDC_HQR_VALUE, wxTextCtrl)->GetValue();
-		if(atoi(buffer))
-		{
+		if(atoi(buffer)) {
 			int hqr = atoi(buffer);
-			if((hqr <= 3000) && (hqr >= 300)) {
+			if((hqr <= 3000)&& (hqr >= 300)) {
 				app_prefs->prefs->HighQueueRanking = hqr;
 			} else {
 				GetDlgItem(IDC_HQR_VALUE, wxTextCtrl)->SetValue(strBuffer);
@@ -114,14 +120,13 @@ void CPPgSourcesDropping::OnApply()
 			GetDlgItem(IDC_HQR_VALUE, wxTextCtrl)->SetValue(strBuffer);
 		}
 	}
-	/* Get the Auto Drop Timer from Dialog */
+    /* Get the Auto Drop Timer from Dialog */
 	strBuffer.Format("%d", app_prefs->prefs->AutoDropTimer);
 	if (GetDlgItem(IDC_AUTO_DROP_TIMER, wxTextCtrl)->GetValue()) {
 		buffer = GetDlgItem(IDC_AUTO_DROP_TIMER, wxTextCtrl)->GetValue();
-		if(atoi(buffer))
-		{
+		if(atoi(buffer)) {
 			int hqr = atoi(buffer);
-			if((hqr <= 3600) && (hqr >= 60)) {
+			if((hqr <= 3600)&& (hqr >= 60)) {
 				app_prefs->prefs->AutoDropTimer = hqr;
 			} else {
 				GetDlgItem(IDC_AUTO_DROP_TIMER, wxTextCtrl)->SetValue(strBuffer);
@@ -131,3 +136,5 @@ void CPPgSourcesDropping::OnApply()
 		}
 	}
 }
+
+
