@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -18,7 +22,10 @@
 #ifndef OTHERFUNS_H
 #define OTHERFUNS_H
 
+#include "mfc.h"
 #include "types.h"
+#include "wintypes.h"
+
 #include <math.h>
 #include <sys/time.h>
 
@@ -45,6 +52,7 @@ void MakeFoldername(char* path);
 void URLDecode(wxString& result, const char* buff);// Make a malloc'd decoded strnig from an URL encoded string (with escaped spaces '%20' and  the like
 wxString URLEncode(wxString sIn);
 inline BYTE toHex(const BYTE &x);
+int GetFTIDbyName(wxString infile);
 wxString GetFiletypeByName(wxString infile);
 bool Ask4RegFix(bool checkOnly, bool dontAsk = false); // Barry - Allow forced update without prompt
 void BackupReg(void); // Barry - Store previous values
@@ -125,5 +133,6 @@ inline long GetTickCount()
   return secs;
 }
 
+bool SafeCopyFile(const wxString& file1, const wxString& file2);
 
 #endif
