@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -22,10 +26,9 @@
 #include "types.h"
 #include "opcodes.h"
 #include "otherstructs.h"
+//#include "zlib/zlib.h"
 #include "CFile.h"
 #include <exception>
-#include <zlib.h>
-
 //			CLIENT TO SERVER
 
 
@@ -39,6 +42,9 @@ public:
 	Packet(char* pPacketPart,uint32 nSize,bool bLast); // only used for splitted packets!
 	Packet(CMemFile* datafile,uint8 protocol = OP_EDONKEYPROT);
 	Packet(int8 in_opcode,int32 in_size,uint8 protocol = OP_EDONKEYPROT);
+	Packet(int8 in_opcode,int32 in_size,uint8 protocol, unsigned char *buffer);
+	Packet(char* type,int8 in_opcode,int32 in_size,uint8 protocol = OP_EDONKEYPROT,bool bFromPF = true);
+	Packet(char* type,char* pPacketPart,uint32 nSize,bool bLast,bool bFromPF = true);//only used for spl. packets!
 	~Packet();
 	char*	GetHeader();
 	char*	GetUDPHeader();
@@ -53,6 +59,9 @@ public:
 	uint32	size;
 	uint8	opcode;
 	uint8	prot;
+	// -khaos--+++> Returns either -1, 0 or 1.  -1 is unset, 0 is from complete file, 1 is from part file
+	bool	IsFromPF()				{return m_bFromPF;}
+	// <-----khaos-
 private:
 	bool	m_bSplitted;
 	bool	m_bLastSplitted;
@@ -60,6 +69,7 @@ private:
 	char*	completebuffer;
 	char*	tempbuffer;
 	bool	m_bPacked;
+	int	m_bFromPF;
 };
 struct Tag_Struct{
 	int8	type;
