@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -64,16 +68,32 @@ extern inline long GetTickCount();
 #define	MS_CONNECTING		2
 #define	MS_UNABLETOCONNECT	3
 
-// clientsoft
-#define SO_EMULE			0
-#define SO_CDONKEY			1
-#define SO_xmule			2
-#define SO_EDONKEYHYBRID	50
-#define	SO_EDONKEY			51
-#define SO_MLDONKEY			52
-#define SO_NEW_MLDONKEY			152
-#define SO_OLDEMULE			53
-#define SO_UNKNOWN			54
+enum EClientSoftware {
+	SO_EMULE			= 0,
+	SO_CDONKEY			= 1,
+	SO_XMULE			= 2,
+	SO_SHAREAZA			= 4,
+	SO_EDONKEYHYBRID	= 50,
+	SO_EDONKEY			= 51,
+	SO_MLDONKEY			= 52,
+	SO_OLDEMULE			= 53,
+	SO_UNKNOWN			= 54,
+	SO_NEW_MLDONKEY			= 153,
+};
+
+enum ESecureIdentState {
+	IS_UNAVAILABLE = 0,
+	IS_ALLREQUESTSSEND = 0,
+	IS_SIGNATURENEEDED = 1,
+	IS_KEYANDSIGNEEDED =2,
+};
+
+enum EInfoPacketState {
+	IP_NONE = 0,
+	IP_EDONKEYPROTPACK = 1,
+	IP_EMULEPROTPACK = 2,
+	IP_BOTH = 3,
+};
 
 class CClientReqSocket;
 class CFriend;
@@ -88,9 +108,10 @@ public:
 	~CUpDownClient();
 	void			Destroy();
 	void			Disconnected();
-	void			TryToConnect(bool bIgnoreMaxCon = false);
+	bool			TryToConnect(bool bIgnoreMaxCon = false);
 	void			ConnectionEstablished();
 	uint32			GetUserID()					{return m_nUserID;}
+	void			SetUserID(wxUint32 nUserID)			{ m_nUserID=nUserID; }
 	char*			GetUserName()				{return m_pszUsername;}
 	uint32			GetIP()						{return m_dwUserIP;}
 	bool			HasLowID()					{return (m_nUserID < 16777216);}
@@ -99,18 +120,22 @@ public:
 	uint32			GetTransferedUp()			{return m_nTransferedUp;}
 	uint32			GetTransferedDown()			{return m_nTransferedDown;}
 	uint32			GetServerIP()				{return m_dwServerIP;}
+	void			SetServerIP(wxUint32 nIP)		{ m_dwServerIP=nIP; }
 	uint16			GetServerPort()				{return m_nServerPort;}
+	void			SetServerPort(wxUint16 nPort)		{ m_nServerPort=nPort; }
 	uchar*			GetUserHash()				{return (uchar*)m_achUserHash;}
-	void			SetUserHash(uchar* achUserHash)		{if(achUserHash) memcpy(m_achUserHash,achUserHash,16); else memset(m_achUserHash,0,16); }
+	void			SetUserHash(uchar* achUserHash);
 	bool			HasValidHash()				{return ((int*)m_achUserHash)[0] != 0 || ((int*)m_achUserHash)[1] != 0 ||
 												        ((int*)m_achUserHash)[2] != 0 || ((int*)m_achUserHash)[3] != 0; }
+	int			GetHashType();
 	uint32			GetVersion()				{return m_nClientVersion;}
 	uint8			GetMuleVersion()			{return m_byEmuleVersion;}
 	bool			ExtProtocolAvailable()		{return m_bEmuleProtocol;}
 	bool			IsEmuleClient()				{return m_byEmuleVersion;}
 	CClientCredits* Credits()					{return credits;}
-	bool			IsBanned()					{return (m_bBanned && m_nDownloadState != DS_DOWNLOADING);}
+	bool			IsBanned()	{return (m_bBanned && m_nDownloadState != DS_DOWNLOADING);}
 	char*			GetClientFilename()			{return m_pszClientFilename;}
+	wxString		GetClientFilename_NEW() const		{return m_strClientFilename;}
 	bool			SupportsUDP()				{return m_byUDPVer != 0 && m_nUDPPort != 0;}
 	uint16			GetUDPPort()				{return m_nUDPPort;}
 	void			SetUDPPort(uint16 nPort)	{ m_nUDPPort = nPort; }
@@ -126,7 +151,7 @@ public:
         wxString                 GetUploadFileInfo();
 
 	void			SetUserName(char* pszNewName);
-	uint8			GetClientSoft()				{return m_clientSoft;}
+	EClientSoftware		GetClientSoft()				{return m_clientSoft;}
 	void			ReGetClientSoft();
 	void			ProcessHelloAnswer(char* pachPacket, uint32 nSize);
 	void			ProcessHelloPacket(char* pachPacket, uint32 nSize);
@@ -138,12 +163,20 @@ public:
 	bool			Compare(CUpDownClient* tocomp);
 	void			SetLastSrcReqTime()			{m_dwLastSourceRequest = ::GetTickCount();}
 	void			SetLastSrcAnswerTime()		{m_dwLastSourceAnswer = ::GetTickCount();}
+	void			SetLastAskedForSources()	{m_dwLastAskedForSources = ::GetTickCount();}
 	uint32			GetLastSrcReqTime()			{return m_dwLastSourceRequest;}
 	uint32			GetLastSrcAnswerTime()		{return m_dwLastSourceAnswer;}
+	uint32			GetLastAskedForSources()	{ return m_dwLastAskedForSources;}
 	bool			GetFriendSlot()				{return m_bFriendSlot;}
 	void			SetFriendSlot(bool bNV)		{m_bFriendSlot = bNV;}
 	void			SetCommentDirty(bool bDirty = true) {m_bCommentDirty = bDirty;}
 	uint8			GetSourceExchangeVersion()	{return m_bySourceExchangeVer;}
+	uint8			GetSecureIdentState()		{return m_SecureIdentState;}
+	void			SendSecIdentStatePacket();
+	void			InfoPacketsReceived();
+
+	bool			SupportsPreview()		{return m_bSupportsPreview;}
+	bool			SafeSendPacket(Packet* packet);
 
 	CClientReqSocket*	socket;
 	CClientCredits*		credits;
@@ -210,10 +243,11 @@ public:
 	void			SetRemoteQueueRank(uint16 nr);
 	void			DrawStatusBar(wxMemoryDC* dc, wxRect rect, bool onlygreyrect, bool  bFlat);
 	void			AskForDownload();
+	void			SendFileRequest_HOPE();
 	void			SendFileRequest();
 	void			ProcessFileInfo(char* packet,uint32 size);
 	void			ProcessFileStatus(char* packet,uint32 size);
-	void			ProcessHashSet(char* packet,uint32 size);
+	void			ProcessHashSet(unsigned char* packet,uint32 size);
 	bool			AddRequestForAnotherFile(CPartFile* file);
 	void			SendBlockRequests();
 	void			ProcessBlockPacket(char* packet, uint32 size, bool packed = false);
@@ -278,17 +312,24 @@ private:
 	uint8	m_byAcceptCommentVer;
 	uint8	m_byExtendedRequestsVer;
 	uint8	m_cFailed;
-	uint8	m_clientSoft;
+	EClientSoftware	m_clientSoft;
 	uint32	m_dwLastSourceRequest;
 	uint32	m_dwLastSourceAnswer;
+	uint32  m_dwLastAskedForSources;
 	int	m_iFileListRequested;
 	bool	m_bFriendSlot;
 	bool	m_bCommentDirty;
 	bool	m_bIsHybrid;
-	bool	m_bIsNewMLD;
-	uint32	m_byCompatableClient;
+	bool	m_bIsML;
+	uint32	m_byCompatibleClient;
 	CTypedPtrList<CPtrList, Packet*>				 m_WaitingPackets_list;
 	DWORD	m_lastRefreshedDLDisplay;
+	ESecureIdentState	m_SecureIdentState;
+	uint8	m_byInfopacketsReceived;
+	uint32	m_dwLastSignatureIP;
+	uint8	m_bySupportSecIdent;
+	bool	m_bSupportsPreview;
+	
 
 	//upload
 	void CreateStandartPackets(byte* data,uint32 togo, Requested_Block_Struct* currentblock);
@@ -314,7 +355,8 @@ private:
 	uint32		m_nSumForAvgUpDataRate;
 
 	private:
-	CList<int,int>									 m_AvarageUDR_list;
+	CList<int,int>	 m_AvarageUDR_list;
+	
 	CTypedPtrList<CPtrList, Packet*>				 m_BlockSend_queue;
 	CTypedPtrList<CPtrList, Requested_Block_Struct*> m_BlockRequests_queue;
 	CTypedPtrList<CPtrList, Requested_Block_Struct*> m_DoneBlocks_list;
@@ -327,6 +369,7 @@ private:
 	uint32		m_cDownAsked;
 	uint8*		m_abyPartStatus;
 	uint32		m_dwLastAskedTime;
+	wxString	m_strClientFilename;
 	char*		m_pszClientFilename;
 	uint32		m_nTransferedDown;
 	uint32      m_nLastBlockOffset;   // Patch for show parts that you download [Cax2]
@@ -341,8 +384,11 @@ private:
 	bool		m_bUDPPending;
 	uint32		m_nSumForAvgDownDataRate;
 	bool		m_bHashsetRequested;
+	bool		m_fSharedDirectories;
 
-	CList<int,int>									 m_AvarageDDR_list;
+	CList<int,int>	 m_AvarageDDR_list;
+	sint32		sumavgDDR;
+	sint32		sumavgUDR;
 	CTypedPtrList<CPtrList, Pending_Block_Struct*>	 m_PendingBlocks_list;
  // CTypedPtrList<CPtrList, CPartFile*>	 m_OtherRequests_list;    ---> See Razor 1a modif  : becomes public
 	CTypedPtrList<CPtrList, Requested_Block_Struct*> m_DownloadBlocks_list;
