@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -18,13 +22,25 @@
 #ifdef PRECOMP
 #	include "xmule-headers.h"
 #else
+#	include "ChatWnd.h"
 #	include "config.h"
+#	include "ClientList.h"
+#	include "ClientUDPSocket.h"
+#	include "DownloadQueue.h"
+#	include "FriendList.h"
+#	include "IPFilter.h"
+#	include "muuli_wdr.h"
+#	include "opcodes.h"
+#	include "PreferencesDlg.h"
+#	include "SearchList.h"
+#	include "ServerWnd.h"
+#	include "SharedFilesWnd.h"
+#	include "StatisticsDlg.h"
+#	include "TransferWnd.h"
+#	include "UploadQueue.h"
 #	include "xmule.h"
 #	include "xmuleDlg.h"
-#	include "opcodes.h"
-#	include "IPFilter.h"
 #	include "WebServer.h"
-#	include "muuli_wdr.h"
 #endif
 
 #ifdef _DEBUG
@@ -43,6 +59,7 @@
 #include "wx/xrc/xmlres.h"
 
 #include <sys/socket.h>
+#include <sys/stat.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
@@ -69,18 +86,16 @@ void InitSplashXRC();
 # define RLIMIT_RESOURCE int
 #endif
 
-static void UnlimitResource(RLIMIT_RESOURCE resType)
-{
+static void UnlimitResource(RLIMIT_RESOURCE resType) {
 #if defined(HAVE_GETRLIMIT) && defined(HAVE_SETRLIMIT)
 	struct rlimit rl;
-	getrlimit(resType, &rl);
+	getrlimit(resType,&rl);
 	rl.rlim_cur = rl.rlim_max;
-	setrlimit(resType, &rl);
+	setrlimit(resType,&rl);
 #endif
 }
 
-static void SetResourceLimits()
-{
+static void SetResourceLimits() {
 #ifdef HAVE_SYS_RESOURCE_H
 	UnlimitResource(RLIMIT_DATA);
 	UnlimitResource(RLIMIT_FSIZE);
@@ -90,59 +105,20 @@ static void SetResourceLimits()
 }
 
 
-CxmuleApp::CxmuleApp()
-{
-
+CxmuleApp::CxmuleApp() {
 }
 
-CxmuleApp::~CxmuleApp()
-{
-	delete listensocket;
+CxmuleApp::~CxmuleApp() {
+	listensocket->Destroy();
 }
 
-int CxmuleApp::OnExit()
-{
-	/*
-	 * The following destruction sequence was moved to the
-	 * destructor of the dialog since some of them call
-	 * functions accessing controls of the dialog.
-	 */
-#if 0
-	/* Clear up the Online Signature file. */
-	OnlineSig(true);
-
-	theApp.listensocket->Destroy();
-	theApp.clientudp->Destroy();
-	delete theApp.sharedfiles;
-	delete theApp.serverconnect;
-	delete theApp.serverlist;
-	delete theApp.knownfiles;
-	delete theApp.searchlist;
-	delete theApp.clientcredits;
-	delete theApp.downloadqueue;
-	delete theApp.uploadqueue;
-	delete theApp.clientlist;
-	delete theApp.friendlist;
-	delete theApp.glob_prefs;
-#endif
-
-#if 0
-	delete searchlist;
-	delete friendlist;
-	delete knownfiles;
-	delete serverlist;
-	delete serverconnect;
-	delete sharedfiles;
-	delete listensocket;
-	delete clientudp;
-	delete clientcredits;
-	delete downloadqueue;
-	delete uploadqueue;
-	delete clientlist;
-#endif
-
+int CxmuleApp::OnExit() {
+ /*
+ * The following destruction sequence was moved to the
+ * destructor of the dialog since some of them call
+ * functions accessing controls of the dialog.
+    */
 	printf("xMule shutdown completed.\n");
-
 	return wxApp::OnExit();
 }
 
@@ -152,21 +128,16 @@ int CxmuleApp::OnExit()
 
 // IPC classes
 
-class MuleConnection:public wxConnection 
-{
-  public:
-	MuleConnection(void):wxConnection() 
-  	{
+class MuleConnection:public wxConnection {
+	public:
+	MuleConnection(void) :wxConnection() {
 	};
-	~MuleConnection(void) 
-	{
+	~MuleConnection(void) {
 	};
-	bool OnAdvise(const wxString & topic, const wxString & item, char *data, int size, wxIPCFormat format) 
-	{
+	bool OnAdvise(const wxString& topic, const wxString& item, char *data, int size, wxIPCFormat format) {
 		return TRUE;
 	}
-	virtual char *OnRequest(const wxString & topic, const wxString & item, int *size, wxIPCFormat format) 
-	{
+	virtual char *OnRequest(const wxString& topic, const wxString& item, int *size, wxIPCFormat format) {
 		if (item == "STATS") {
 			int filecount = theApp.downloadqueue->GetFileCount();
 			// get the source count
@@ -178,15 +149,15 @@ class MuleConnection:public wxConnection
 		}
 		return "";
 	}
-	bool OnExecute(const wxString & topic, /*const wxString& item, */ char *data, int size, wxIPCFormat format) 
-	{
+    bool OnExecute(const wxString& topic, /*const wxString& item, */
+	char *data, int size, wxIPCFormat format) {
 		wxString item = "ED2KLINK";
 		if (item == "ED2KLINK") {
 			// add it to queue
 			try {
 				wxString edlink = data;
 				if (edlink.Right(1) != "/")
-					edlink += "/";
+				edlink+= "/";
 				edlink.Replace("%7c", "|");
 				edlink.Replace("%7C", "|");
 				wxString newlink;
@@ -194,41 +165,36 @@ class MuleConnection:public wxConnection
 				printf("Link is %s\n", newlink.GetData());
 				CED2KLink *pLink = CED2KLink::CreateLinkFromUrl(newlink);
 				switch (pLink->GetKind()) {
-					case CED2KLink::kFile:
-						{
-							CED2KFileLink *pFileLink = pLink->GetFileLink();
-							theApp.downloadqueue->AddFileLinkToDownload(pFileLink);
-						}
-						break;
-					case CED2KLink::kServerList:
-						{
-							CED2KServerListLink *pListLink = pLink->GetServerListLink();
-							CString strAddress = pListLink->GetAddress();
-							if (strAddress.GetLength() != 0)
-								theApp.xmuledlg->serverwnd->UpdateServerMetFromURL(strAddress);
-						}
-						break;
-					case CED2KLink::kServer:
-						{
-							CString defName;
-							CED2KServerLink *pSrvLink = pLink->GetServerLink();
-							in_addr host;
-							host.s_addr = pSrvLink->GetIP();
-							CServer *pSrv = new CServer(pSrvLink->GetPort(), inet_ntoa(host));
-							pSrvLink->GetDefaultName(defName);
-							pSrv->SetListName((char *)(defName.GetData()));
-
-							// Barry - Default all new servers to high priority
-							pSrv->SetPreference(PR_HIGH);
-
-							if (!theApp.xmuledlg->serverwnd->serverlistctrl->AddServer(pSrv, true))
-								delete pSrv;
-							else
+				case CED2KLink::kFile: {
+					CED2KFileLink *pFileLink = pLink->GetFileLink();
+						theApp.downloadqueue->AddFileLinkToDownload(pFileLink);
+					}
+					break;
+				case CED2KLink::kServerList: {
+					CED2KServerListLink *pListLink = pLink->GetServerListLink();
+						CString strAddress = pListLink->GetAddress();
+						if (strAddress.GetLength() != 0)
+						theApp.xmuledlg->serverwnd->UpdateServerMetFromURL(strAddress);
+					}
+					break;
+				case CED2KLink::kServer: {
+					CString defName;
+						CED2KServerLink *pSrvLink = pLink->GetServerLink();
+						in_addr host;
+						host.s_addr = pSrvLink->GetIP();
+						CServer *pSrv = new CServer(pSrvLink->GetPort(), inet_ntoa(host));
+						pSrvLink->GetDefaultName(defName);
+						pSrv->SetListName((char *) (defName.GetData()));
+						// Barry - Default all new servers to high priority
+						pSrv->SetPreference(PR_HIGH);
+						if (!theApp.xmuledlg->serverwnd->serverlistctrl->AddServer(pSrv, true))
+						delete pSrv;
+						else
 								theApp.xmuledlg->AddLogLine(true, GetResString(IDS_SERVERADDED)+"%s", pSrv->GetListName());
-						}
-						break;
-					default:
-						break;
+					}
+					break;
+				default:
+					break;
 				}
 				delete pLink;
 			}
@@ -239,25 +205,20 @@ class MuleConnection:public wxConnection
 	}
 };
 
-class MuleClient:public wxClient 
-	{
-  public:
-	MuleClient(void) 
-	{
+class MuleClient:public wxClient {
+	public:
+	MuleClient(void) {
 	};
-	wxConnectionBase *OnMakeConnection(void) 
-	{
+	wxConnectionBase *OnMakeConnection(void) {
 		return new MuleConnection;
 	}
 };
 
 class MuleServer:public wxServer {
-  public:
-	MuleServer(void) 
-	{
+	public:
+	MuleServer(void) {
 	};
-	wxConnectionBase *OnAcceptConnection(const wxString & topic) 
-	{
+	wxConnectionBase *OnAcceptConnection(const wxString& topic) {
 		return new MuleConnection;
 	}
 };
@@ -266,10 +227,8 @@ class MuleServer:public wxServer {
 
 extern void InitXmlResource();
 
-bool CxmuleApp::OnInit()
-{
+bool CxmuleApp::OnInit() {
 	clientlist = NULL;
-	searchlist = NULL;
 	friendlist = NULL;
 	knownfiles = NULL;
 	serverlist = NULL;
@@ -281,19 +240,14 @@ bool CxmuleApp::OnInit()
 	downloadqueue = NULL;
 	uploadqueue = NULL;
 	ipfilter = NULL;
-
 	// catch fatal exceptions
 	wxHandleFatalExceptions(true);
-
 	//putenv("LANG=en_US");
-
 	SetResourceLimits();
-
 	// for resources
 	wxFileSystem::AddHandler(new wxZipFSHandler);
 	wxXmlResource::Get()->InitAllHandlers();
 	InitXmlResource();
-
 	for (int i = 1; i < argc; i++) {
 		if (strncmp(argv[i], "--version", 7) == 0) {
 			printf("%s version %s\n", PACKAGE_NAME, PACKAGE_VERSION);
@@ -301,29 +255,22 @@ bool CxmuleApp::OnInit()
 			exit(0);
 		}
 	}
-
 	printf("Initialising xMule\n");
-
 	close(0);
-
 	//if(ProcessCommandLine())
 	//  return FALSE;
-
 	//SetTopWindow(dlg);
-
 	SetVendorName("TikuWarez");
-
 	// Do NOT change this string to xMule nor anything else, it WILL fuck you up.
 	SetAppName("eMule");
-
-	/* Madcat - This code part is no longer neccesery, because external ED2K links are
-		handled by the 'ed2k' program, and for statistics, it is easier (and faster)
-		to use the online signature. Besides, disabling this code part will lower
-		memory usage and speed up startup times.
-	*/
-	#if 0
+ /* Madcat - This code part is no longer neccesery, because external ED2K links are
+ handled by the 'ed2k' program, and for statistics, it is easier (and faster)
+ to use the online signature. Besides, disabling this code part will lower
+ memory usage and speed up startup times.
+    */
+#if 0
 	// see if there is another instance running
-	wxString server = getenv("HOME") + wxString("/.xMule/muleconn");
+	wxString server = getenv("HOME")+ wxString("/.xMule/muleconn");
 	wxString hostName = "localhost";
 	MuleClient *client = new MuleClient;
 	MuleConnection *conn = (MuleConnection *) client->MakeConnection(hostName, server, "xMule IPC");
@@ -351,53 +298,54 @@ bool CxmuleApp::OnInit()
 		delete conn;
 		delete client;
 		// don't allow another instance.
-		sleep(1);	// this will prevent xmule to hang itself     
-		exit(0);	// is this clean.. perhaps not
+		// this will prevent xmule to hang itself:
+		sleep(1);
+		// is this clean.. perhaps not:
+		exit(0);
 	}
-
 	delete conn;
-	#endif
+#endif
 	m_locale.Init(wxLANGUAGE_DEFAULT);
 	m_locale.AddCatalogLookupPathPrefix(LOCALEDIR);
 	m_locale.AddCatalog(PACKAGE);
-
 	CxmuleDlg *dlg = new CxmuleDlg(NULL, wxString::Format(wxT("%s v%s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION)));
 	xmuledlg = dlg;
 	dlg->Show(TRUE);
-
 	// Madcat - Check if prefs can be found at ~/.lmule and rename as neccesery.
-
-	wxString OldPrefDir = getenv("HOME") + wxString("/.lmule");
-	wxString NewPrefDir = getenv("HOME") + wxString("/.xMule");
-	if (wxDirExists(OldPrefDir) && !wxDirExists(NewPrefDir)) {
+	wxString OldPrefDir = getenv("HOME")+ wxString("/.lmule");
+	wxString NewPrefDir = getenv("HOME")+ wxString("/.xMule");
+	if (wxDirExists(OldPrefDir)&& !wxDirExists(NewPrefDir)) {
 		printf("Found old settings, moving to new dir.\n");
 		wxRenameFile(OldPrefDir, NewPrefDir);
 	}
+	if (!wxDirExists(NewPrefDir)) {
+		mkdir(NewPrefDir,0777);
+	}
+	wxString filename = NewPrefDir+ wxString("/server.met");
+	if (!wxFileExists(filename)) {
+		wxFile metfile(filename, wxFile::write_excl);
+		if (metfile.IsOpened()) {
+			metfile.Close();
+		}
+	}
 	// Delete old log file.
 	wxRemoveFile(wxString::Format("%s/.xMule/logfile", getenv("HOME")));
-
 	glob_prefs = new CPreferences();
 	xmuledlg->preferenceswnd->SetPrefs(glob_prefs);
-
-	xmuledlg->createSystray(wxString::Format(wxT("%s v%s"),	wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION)));
-
+	xmuledlg->createSystray(wxString::Format(wxT("%s v%s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION)));
 	// splashscreen
-	if (theApp.glob_prefs->UseSplashScreen() && !theApp.glob_prefs->GetStartMinimized()) {
+	if (theApp.glob_prefs->UseSplashScreen()&& !theApp.glob_prefs->GetStartMinimized()) {
 		InitSplashXRC();
 		wxImage::AddHandler(new wxJPEGHandler);
-		
 		wxSplashScreen* splsh=new wxSplashScreen(wxXmlResource::Get()->LoadBitmap("About"),wxSPLASH_CENTRE_ON_SCREEN|wxSPLASH_TIMEOUT,
-							 5000,NULL,-1,wxDefaultPosition,wxDefaultSize,
-							 wxSIMPLE_BORDER|wxSTAY_ON_TOP);
+		5000,NULL,-1,wxDefaultPosition,wxDefaultSize,
+		wxSIMPLE_BORDER|wxSTAY_ON_TOP);
 	}
-
 	wxIPV4address myaddr;
 	myaddr.AnyAddress();
 	myaddr.Service(glob_prefs->GetPort());
 	printf("*** TCP socket at %d\n", glob_prefs->GetPort());
-
 	clientlist = new CClientList();
-	searchlist = new CSearchList();
 	friendlist = new CFriendList();
 	knownfiles = new CKnownFileList(glob_prefs->GetAppDir());
 	serverlist = new CServerList(glob_prefs);
@@ -406,33 +354,27 @@ bool CxmuleApp::OnInit()
 	myaddr.Service(glob_prefs->GetUDPPort());
 	clientudp = new CClientUDPSocket(myaddr);
 	clientcredits = new CClientCreditsList(glob_prefs);
-	downloadqueue = new CDownloadQueue(glob_prefs, sharedfiles);	// bugfix - do this before creating the uploadqueue
+	// bugfix - do this before creating the uploadqueue:
+	downloadqueue = new CDownloadQueue(glob_prefs, sharedfiles);
 	uploadqueue = new CUploadQueue(glob_prefs);
 	ipfilter = new CIPFilter();
 	webserver = new CWebServer();
 	//INT_PTR nResponse = dlg.DoModal();
-
 	// init statistics stuff, better do it asap
 	xmuledlg->statisticswnd->Init();
 	xmuledlg->statisticswnd->ShowInterval();
-
-	// must do initialisations here.. 
+	// must do initialisations here..
 	xmuledlg->serverwnd->serverlistctrl->Init(serverlist);
 	serverlist->Init();
-
 	// ini. downloadqueue
 	theApp.downloadqueue->Init();
 	xmuledlg->AddLogLine(true, PACKAGE_STRING);
-
-	// 
+	//
 	theApp.sharedfiles->SetOutputCtrl((CSharedFilesCtrl *) xmuledlg->sharedfileswnd->FindWindowByName("sharedFilesCt"));
-
 	// then init firend list
 	theApp.friendlist->SetWindow((CFriendListCtrl *) theApp.xmuledlg->chatwnd->FindWindowById(ID_FRIENDLIST));
 	theApp.friendlist->ShowFriends();
-
 	SetTopWindow(dlg);
-
 	// reset statistic values
 	theApp.stat_sessionReceivedBytes = 0;
 	theApp.stat_sessionSentBytes = 0;
@@ -440,7 +382,6 @@ bool CxmuleApp::OnInit()
 	theApp.stat_transferStarttime = 0;
 	theApp.stat_serverConnectTime = 0;
 	theApp.Start_time = GetTickCount();
-
 	// Initialize and sort all lists.
 	// FIX: Remove from here and put these back to the OnInitDialog()s
 	// and call the OnInitDialog()s here!
@@ -454,18 +395,15 @@ bool CxmuleApp::OnInit()
 	theApp.xmuledlg->serverwnd->serverlistctrl->InitSort();
 	theApp.xmuledlg->sharedfileswnd->sharedfilesctrl->LoadSettings(CPreferences::tableShared);
 	theApp.xmuledlg->sharedfileswnd->sharedfilesctrl->InitSort();
-
 	// call the initializers
 	theApp.xmuledlg->transferwnd->OnInitDialog();
-
 	xmuledlg->m_app_state = APP_STATE_RUNNING;
-	
-	/* Madcat - This code part is no longer neccesery, because external ED2K links are
-		handled by the 'ed2k' program, and for statistics, it is easier (and faster)
-		to use the online signature. Besides, disabling this code part will lower
-		memory usage and speed up startup times.
-	*/
-	#if 0
+ /* Madcat - This code part is no longer neccesery, because external ED2K links are
+ handled by the 'ed2k' program, and for statistics, it is easier (and faster)
+ to use the online signature. Besides, disabling this code part will lower
+ memory usage and speed up startup times.
+    */
+#if 0
 	// parse possible arguments
 	// easy way: just create a client connection and stuff them there :)
 	// note: not actually SENDING anything, just passing stuff directly
@@ -481,30 +419,25 @@ bool CxmuleApp::OnInit()
 				}
 			}
 		}
-		// we'll leave it lying around.. 
+		// we'll leave it lying around..
 		// (can't delete it :)
 	}
-	#endif
-	
+#endif
 	// reload shared files
 	theApp.sharedfiles->Reload(true, true);
-
 	if (glob_prefs->GetWSIsEnabled()) {
 		webserver->ReloadTemplates();
 		webserver->StartServer();
 	}
-
 	myaddr.Service(glob_prefs->GetPort());
 	listensocket = new CListenSocket(glob_prefs, myaddr);
-
 	if (!listensocket->Ok()) {
 		xmuledlg->AddLogLine(false, (_("Port %d is not available. You will be LOWID")), glob_prefs->GetPort());
 		CString str;
 		str.Format(_("Port %d is not available !!\n\nThis will mean that you will be LOWID.\n\nUse netstat to determine when port becomes available\nand try starting xmule again."), glob_prefs->GetPort());
-		wxMessageBox(str, _("Error"), wxCENTRE | wxOK | wxICON_ERROR);
+		wxMessageBox(str, _("Error"), wxCENTRE| wxOK| wxICON_ERROR);
 	}
-
-	// pretty much ready now. start autoconnect if 
+	// pretty much ready now. start autoconnect if
 	if (theApp.glob_prefs->DoAutoConnect()) {
 		wxCommandEvent nullEvt;
 		theApp.xmuledlg->OnBnConnect(nullEvt);
@@ -517,12 +450,10 @@ bool CxmuleApp::OnInit()
 }
 
 #if 0
-BOOL CxmuleApp::InitInstance()
-{
+BOOL CxmuleApp::InitInstance() {
 #ifdef _DUMP
 	MiniDumper dumper(CURRENT_VERSION_LONG);
 #endif
-
 	pendinglink = 0;
 	if (ProcessCommandline()) {
 		return false;
@@ -531,112 +462,96 @@ BOOL CxmuleApp::InitInstance()
 	// die Verwendung von ComCtl32.dll Version 6 oder hher zum Aktivieren
 	// von visuellen Stilen angibt. Ansonsten treten beim Erstellen von Fenstern Fehler auf.
 	InitCommonControls();
-
 	CWinApp::InitInstance();
-
 	if (!AfxSocketInit()) {
 		AfxMessageBox(IDP_SOCKETS_INIT_FAILED);
 		return FALSE;
 	}
-
 	AfxEnableControlContainer();
 	AfxSocketInit();
 	CxmuleDlg dlg;
-	xmuledlg = &dlg;
-	m_pMainWnd = &dlg;
-
-	// create & initalize all the important stuff 
+	xmuledlg =&dlg;
+	m_pMainWnd =&dlg;
+	// create & initalize all the important stuff
 	glob_prefs = new CPreferences();
-
-	//setup languag 
+	//setup languag
 	clientlist = new CClientList();
-	searchlist = new CSearchList();
 	knownfiles = new CKnownFileList(glob_prefs->GetAppDir());
 	serverlist = new CServerList(glob_prefs);
 	serverconnect = new CServerConnect(serverlist, theApp.glob_prefs);
 	sharedfiles = new CSharedFileList(glob_prefs, serverconnect, knownfiles);
 	listensocket = new CListenSocket(glob_prefs);
 	clientcredits = new CClientCreditsList(glob_prefs);
-	downloadqueue = new CDownloadQueue(glob_prefs, sharedfiles);	// bugfix - do this before creating the uploadqueue
+	// bugfix - do this before creating the uploadqueue:
+	downloadqueue = new CDownloadQueue(glob_prefs, sharedfiles);
 	uploadqueue = new CUploadQueue(glob_prefs);
 	INT_PTR nResponse = dlg.DoModal();
-
-
 	// reset statistic values
 	theApp.stat_sessionReceivedBytes = 0;
 	theApp.stat_sessionSentBytes = 0;
 	theApp.stat_reconnects = 0;
 	theApp.stat_transferStarttime = 0;
 	theApp.stat_serverConnectTime = 0;
-
 	return FALSE;
 }
+
 #endif
 
-bool CxmuleApp::ProcessCommandline()
-{
+bool CxmuleApp::ProcessCommandline() {
 #if 0
 	CCommandLineInfo cmdInfo;
 	ParseCommandLine(cmdInfo);
-
 	char buffer[50];
 	sprintf(buffer, "xMule V%s", CURRENT_VERSION_LONG);
 	HWND maininst = FindWindow(0, buffer);
 	if (cmdInfo.m_nShellCommand == CCommandLineInfo::FileOpen) {
 		CString command = cmdInfo.m_strFileName;
-
-		//if (maininst){ moved down by Cax2 28/10/02 
-		//tagCOPYDATASTRUCT sendstruct; removed by Cax2 28/10/02 
-		sendstruct.cbData = command.GetLength() + 1;
+		//if (maininst){ moved down by Cax2 28/10/02
+		//tagCOPYDATASTRUCT sendstruct; removed by Cax2 28/10/02
+		sendstruct.cbData = command.GetLength()+ 1;
 		sendstruct.dwData = OP_ED2KLINK;
 		sendstruct.lpData = command.GetBuffer();
-		if (maininst) {	//Cax2 28/10/02 
-			SendMessage(maininst, WM_COPYDATA, (WPARAM) 0, (LPARAM) (PCOPYDATASTRUCT) & sendstruct);
+		if (maininst) {
+			//Cax2 28/10/02
+			SendMessage(maininst, WM_COPYDATA, (WPARAM) 0, (LPARAM) (PCOPYDATASTRUCT)& sendstruct);
 			return true;
 		} else {
 			pendinglink = new CString(command);
 		}
 	}
-
 	return maininst;
 #endif
 }
 
-void CxmuleApp::UpdateReceivedBytes(int32 bytesToAdd)
-{
+void CxmuleApp::UpdateReceivedBytes(int32 bytesToAdd) {
 	SetTimeOnTransfer();
-	stat_sessionReceivedBytes += bytesToAdd;
+	stat_sessionReceivedBytes+= bytesToAdd;
 }
 
-void CxmuleApp::UpdateSentBytes(int32 bytesToAdd)
-{
+void CxmuleApp::UpdateSentBytes(int32 bytesToAdd) {
 	SetTimeOnTransfer();
-	stat_sessionSentBytes += bytesToAdd;
+	stat_sessionSentBytes+= bytesToAdd;
 }
 
-void CxmuleApp::SetTimeOnTransfer()
-{
+void CxmuleApp::SetTimeOnTransfer() {
 	if (stat_transferStarttime > 0)
-		return;
-
+	return;
 	stat_transferStarttime = GetTickCount();
 }
 
 typedef char *LPTSTR;
 
-wxString CxmuleApp::StripInvalidFilenameChars(wxString strText, bool bKeepSpaces)
-{
-	LPTSTR pszBuffer = (char *)strText.GetData();
+wxString CxmuleApp::StripInvalidFilenameChars(wxString strText, bool bKeepSpaces) {
+	LPTSTR pszBuffer = (char *) strText.GetData();
 	LPTSTR pszSource = pszBuffer;
 	LPTSTR pszDest = pszBuffer;
-
 	while (*pszSource != '\0') {
-		if (!((*pszSource <= 31 && *pszSource >= 0) ||	// lots of invalid chars for filenames in windows :=)
-			  *pszSource == '\"' || *pszSource == '*' || *pszSource == '<' || *pszSource == '>' || *pszSource == '?' || *pszSource == '|' || *pszSource == '\\' || *pszSource == '/' || *pszSource == ':')) {
-			if (!bKeepSpaces && *pszSource == ' ') {
+		// lots of invalid chars for filenames in windows :=):
+		if (!((*pszSource <= 31&& *pszSource >= 0)||
+		*pszSource == '\"'|| *pszSource == '*'|| *pszSource == '<'|| *pszSource == '>'|| *pszSource == '?'|| *pszSource == '|'|| *pszSource == '\\'|| *pszSource == '/'|| *pszSource == ':')) {
+			if (!bKeepSpaces&& *pszSource == ' ') {
 				*pszDest = '_';
-			}
-			else {
+			} else {
 				*pszDest = *pszSource;
 			}
 			pszDest++;
@@ -644,41 +559,36 @@ wxString CxmuleApp::StripInvalidFilenameChars(wxString strText, bool bKeepSpaces
 		pszSource++;
 	}
 	*pszDest = '\0';
-
 	return strText;
 }
 
-wxString CxmuleApp::CreateED2kLink(CAbstractFile * f)
-{
+wxString CxmuleApp::CreateED2kLink(CAbstractFile * f) {
 	wxString strLink;
-
-	strLink = strLink.Format("ed2k://|file|%s|%d|%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x|/", StripInvalidFilenameChars(f->GetFileName(), true).GetData(),	// spaces to dots
-							 f->GetFileSize(), f->GetFileHash()[0], f->GetFileHash()[1], f->GetFileHash()[2], f->GetFileHash()[3], f->GetFileHash()[4], f->GetFileHash()[5], f->GetFileHash()[6], f->GetFileHash()[7], f->GetFileHash()[8], f->GetFileHash()[9], f->GetFileHash()[10], f->GetFileHash()[11], f->GetFileHash()[12], f->GetFileHash()[13], f->GetFileHash()[14], f->GetFileHash()[15]);
+	// spaces to dots:
+	strLink = strLink.Format("ed2k://|file|%s|%d|%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x|/", StripInvalidFilenameChars(f->GetFileName(), true) .GetData(),
+	f->GetFileSize(), f->GetFileHash() [0], f->GetFileHash() [1], f->GetFileHash() [2], f->GetFileHash() [3], f->GetFileHash() [4], f->GetFileHash() [5], f->GetFileHash() [6], f->GetFileHash() [7], f->GetFileHash() [8], f->GetFileHash() [9], f->GetFileHash() [10], f->GetFileHash() [11], f->GetFileHash() [12], f->GetFileHash() [13], f->GetFileHash() [14], f->GetFileHash() [15]);
 	return strLink.GetData();
 }
 
-wxString CxmuleApp::CreateED2kSourceLink(CAbstractFile * f)
-{
-	if (!serverconnect->IsConnected() || serverconnect->IsLowID()) {
+wxString CxmuleApp::CreateED2kSourceLink(CAbstractFile * f) {
+	if (!serverconnect->IsConnected()|| serverconnect->IsLowID()) {
 		xmuledlg->AddLogLine(true, GetResString(IDS_SOURCELINKFAILED));
 		return CString("");
 	}
 	uint32 dwID = serverconnect->GetClientID();
-
 	wxString strLink;
-	strLink.Printf("ed2k://|file|%s|%u|%s|/|sources,%i.%i.%i.%i:%i|/", StripInvalidFilenameChars(f->GetFileName(), false).GetData(),	// spaces to dots
-				   f->GetFileSize(), EncodeBase16(f->GetFileHash(), 16).GetData(), (uint8) dwID, (uint8) (dwID >> 8), (uint8) (dwID >> 16), (uint8) (dwID >> 24), glob_prefs->GetPort());
+	// spaces to dots:
+	strLink.Printf("ed2k://|file|%s|%u|%s|/|sources,%i.%i.%i.%i:%i|/", StripInvalidFilenameChars(f->GetFileName(), false) .GetData(),
+	f->GetFileSize(), EncodeBase16(f->GetFileHash(), 16) .GetData(), (uint8) dwID, (uint8) (dwID >> 8), (uint8) (dwID >> 16), (uint8) (dwID >> 24), glob_prefs->GetPort());
 	return strLink;
 }
 
-wxString CxmuleApp::CreateHTMLED2kLink(CAbstractFile * f)
-{
-	wxString strCode = "<a href=\"" + CreateED2kLink(f) + "\">" + StripInvalidFilenameChars(f->GetFileName(), true) + "</a>";
+wxString CxmuleApp::CreateHTMLED2kLink(CAbstractFile * f) {
+	wxString strCode = "<a href=\""+ CreateED2kLink(f)+ "\">"+ StripInvalidFilenameChars(f->GetFileName(), true)+ "</a>";
 	return strCode;
 }
 
-bool CxmuleApp::CopyTextToClipboard(wxString strText)
-{
+bool CxmuleApp::CopyTextToClipboard(wxString strText) {
 	if (wxTheClipboard->Open()) {
 		wxTheClipboard->UsePrimarySelection(FALSE);
 		wxTheClipboard->SetData(new wxTextDataObject(strText));
@@ -687,23 +597,24 @@ bool CxmuleApp::CopyTextToClipboard(wxString strText)
 }
 
 
-/* Original implementation by Bouc7 of the eMule Project.
-   xMule Signature idea was designed by BigBob and implemented
-   by Un-Thesis, with design inputs and suggestions from bothie.
-*/
-void CxmuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */) 
-{
+ /* Original implementation by Bouc7 of the eMule Project.
+ xMule Signature idea was designed by BigBob and implemented
+ by Un-Thesis, with design inputs and suggestions from bothie.
+    */
+
+
+    void CxmuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */
+
+) {
 	// Do not do anything if online signature is disabled in Preferences
 	if (!theApp.glob_prefs->IsOnlineSignatureEnabled()) {
 		return;
 	}
-
 	// Build the filenames for the two files
 	char* emulesig_path = new char[strlen(glob_prefs->GetAppDir())+14];
 	char* xmulesig_path = new char[strlen(glob_prefs->GetAppDir())+13];
 	sprintf(emulesig_path,"%sonlinesig.dat",glob_prefs->GetAppDir());
 	sprintf(xmulesig_path,"%sxmulesig.dat",glob_prefs->GetAppDir());
-
 	// Open both files for writing
 	CFile xmulesig_out, emulesig_out;
 	if (!emulesig_out.Open(emulesig_path, CFile::write)) {
@@ -712,9 +623,7 @@ void CxmuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */)
 	if (!xmulesig_out.Open(xmulesig_path, CFile::write)) {
 		theApp.xmuledlg->AddLogLine(true,GetResString(IDS_ERROR_SAVEFILE)+wxString(" xMule OnlineSig File"));
 	}
-
 	char buffer[256];
-
 	if (zero) {
 		emulesig_out.Write("0\n0.0|0.0|0\n", 12);
 		xmulesig_out.Write("0\n0\n0\n0\n0\n0.0\n0.0\n0\n0\n", 22);
@@ -731,7 +640,6 @@ void CxmuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */)
 			emulesig_out.Write("|",1);
 			sprintf(buffer,"%d",serverconnect->GetCurrentServer()->GetPort());
 			emulesig_out.Write(buffer,strlen(buffer));
-
 			// Now for xmule sig
 			xmulesig_out.Write("1",1);
 			xmulesig_out.Write("\n",1);
@@ -741,99 +649,88 @@ void CxmuleApp::OnlineSig(bool zero /* reset stats (used on shutdown) */)
 			xmulesig_out.Write("\n",1);
 			xmulesig_out.Write(buffer,strlen(buffer));
 			xmulesig_out.Write("\n",1);
-
 			// Low- or High-ID (only in xmule sig)
 			if (theApp.serverconnect->IsLowID()) {
 				xmulesig_out.Write("L\n",2);
 			} else {
 				xmulesig_out.Write("H\n",2);
 			}
-		} else {	// Not connected to a server
+		} else {
+			// Not connected to a server
 			emulesig_out.Write("0",1);
 			xmulesig_out.Write("0\n0\n0\n0\n0\n",10);
 		}
 		emulesig_out.Write("\n",1);
-
 		// Datarate for downloads
-		sprintf(buffer,"%.1f",(float)downloadqueue->GetDatarate()/1024);
+		sprintf(buffer,"%.1f",(float) downloadqueue->GetDatarate() /1024);
 		emulesig_out.Write(buffer,strlen(buffer));
 		emulesig_out.Write("|",1);
 		xmulesig_out.Write(buffer,strlen(buffer));
 		xmulesig_out.Write("\n",1);
-
 		// Datarate for uploads
-		sprintf(buffer,"%.1f",(float)uploadqueue->GetDatarate()/1024);
+		sprintf(buffer,"%.1f",(float) uploadqueue->GetDatarate() /1024);
 		emulesig_out.Write(buffer,strlen(buffer));
 		emulesig_out.Write("|",1);
 		xmulesig_out.Write(buffer,strlen(buffer));
 		xmulesig_out.Write("\n",1);
-
 		// Number of users waiting for upload
 		sprintf(buffer,"%d",uploadqueue->GetWaitingUserCount());
 		emulesig_out.Write(buffer,strlen(buffer));
 		xmulesig_out.Write(buffer,strlen(buffer));
 		xmulesig_out.Write("\n",1);
-
 		// Number of shared files
 		sprintf(buffer,"%d", theApp.sharedfiles->GetCount());
 		xmulesig_out.Write(buffer, strlen(buffer));
 		xmulesig_out.Write("\n",1);
-	}	/* if (!zero) */
-
+    } /* if (!zero) */
 	// Nick on the network
 	sprintf(buffer, "%s", theApp.glob_prefs->GetUserNick());
 	xmulesig_out.Write(buffer, strlen(buffer));
 	xmulesig_out.Write("\n",1);
-
 	// Total received in GB
-	sprintf(buffer, "%.2f", (float)(theApp.stat_sessionReceivedBytes+theApp.glob_prefs->GetTotalDownloaded()) / 1073741824);
+	sprintf(buffer, "%.2f", (float) (theApp.stat_sessionReceivedBytes+theApp.glob_prefs->GetTotalDownloaded()) / 1073741824);
 	xmulesig_out.Write(buffer, strlen(buffer));
 	xmulesig_out.Write("\n",1);
-
 	// Total sent in GB
-	sprintf(buffer, "%.2f", (float)(theApp.stat_sessionSentBytes+theApp.glob_prefs->GetTotalUploaded()) / 1073741824);
+	sprintf(buffer, "%.2f", (float) (theApp.stat_sessionSentBytes+theApp.glob_prefs->GetTotalUploaded()) / 1073741824);
 	xmulesig_out.Write(buffer, strlen(buffer));
 	xmulesig_out.Write("\n",1);
-
-	// xmule version 
+	// xmule version
 	sprintf(buffer,"%s", PACKAGE_VERSION);
 	xmulesig_out.Write(buffer, strlen(buffer));
 	xmulesig_out.Write("\n",1);
-
 	// Close the files
 	emulesig_out.Close();
 	xmulesig_out.Close();
 	delete[] emulesig_path;
 	delete[] xmulesig_path;
-} //End Added By Bouc7
+	//End Added By Bouc7:
+}
+
 #if defined(__linux__)
 #include <execinfo.h>
 #endif
 
-void CxmuleApp::OnFatalException()
-{
+void CxmuleApp::OnFatalException() {
 	// Close sockets first.
-	if ( theApp.listensocket )
-		theApp.listensocket->Destroy();
-	if ( theApp.clientudp )
-		theApp.clientudp->Destroy();
-
+	if (theApp.listensocket)
+	theApp.listensocket->Destroy();
+	if (theApp.clientudp)
+	theApp.clientudp->Destroy();
 	// (stkn) create backtrace
 #if defined(__linux__)
-	void *bt_array[100];	// 100 should be enough ?!?
+	// 100 should be enough ?!?:
+	void *bt_array[100];
 	char **bt_strings;
 	int num_entries;
-
 	if ((num_entries = backtrace(bt_array, 100)) < 0) {
 		fprintf(stderr, "* Could not generate backtrace\n");
 		return;
 	}
-
 	if ((bt_strings = backtrace_symbols(bt_array, num_entries)) == NULL) {
 		fprintf(stderr, "* Could not get symbol names for backtrace\n");
 		return;
 	}
-
 	fprintf(stderr, "\nOOPS! - Seems like xMule crashed\n--== BACKTRACE FOLLOWS: ==--\n\n");
 	for (int i = 0; i < num_entries; i++) {
 		fprintf(stderr, "[%d] %s\n", i, bt_strings[i]);
@@ -845,15 +742,14 @@ void CxmuleApp::OnFatalException()
 #define wxGTK_WINDOW 1
 #define SHIFT (8*(sizeof(short int)-sizeof(char)))
 
-static bool GetColourWidget(int &red, int &green, int &blue, int type)
-{
+static bool GetColourWidget(int&red, int&green, int&blue, int type) {
 	GtkWidget *widget;
 	switch (type) {
-		case wxGTK_WINDOW:
-			widget = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-			break;
-		default:
-			return FALSE;
+	case wxGTK_WINDOW:
+		widget = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+		break;
+	default:
+		return FALSE;
 	}
 	GtkStyle *def = gtk_rc_get_style(widget);
 	bool ok = false;
@@ -873,19 +769,19 @@ static bool GetColourWidget(int &red, int &green, int &blue, int type)
 }
 
 // external helper function
-wxColour GetColour(wxSystemColour what)
-{
+wxColour GetColour(wxSystemColour what) {
 	static wxColour *_systemWindowColour = NULL;
-
 	switch (what) {
-		case wxSYS_COLOUR_WINDOW:
-			if (!_systemWindowColour) {
-				int red, green, blue;
-				if (!GetColourWidget(red, green, blue, wxGTK_WINDOW)) {
-					red = green = blue = 0x9c40;
-				}
-				_systemWindowColour = new wxColour(red >> SHIFT, green >> SHIFT, blue >> SHIFT);
+	case wxSYS_COLOUR_WINDOW:
+		if (!_systemWindowColour) {
+			int red, green, blue;
+			if (!GetColourWidget(red, green, blue, wxGTK_WINDOW)) {
+				red = green = blue = 0x9c40;
 			}
-			return *_systemWindowColour;
+			_systemWindowColour = new wxColour(red >> SHIFT, green >> SHIFT, blue >> SHIFT);
+		}
+		return *_systemWindowColour;
 	}
 }
+
+
