@@ -1,5 +1,9 @@
-//this file is part of xMule
-//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+//
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 //This program is free software; you can redistribute it and/or
 //modify it under the terms of the GNU General Public License
@@ -22,38 +26,38 @@
 //	#error include 'stdafx.h' before including this file for PCH
 //#endif
 
-#include "wx/app.h"
-#include <wx/thread.h>
+#include <wx/app.h>
 #include <wx/intl.h>
+#include <wx/settings.h>
+#include <wx/thread.h>
+
+#include "types.h"
+#include "wintypes.h"
+
+class CAbstractFile;
+class CClientCreditsList;
+class CClientList;
+class CClientUDPSocket;
+class CDownloadQueue;
+class CFriendList;
+class CIPFilter;
+class CKnownFileList;
+class CListenSocket;
+class CPreferences;
+class CServerConnect;
+class CServerList;	
+class CSharedFileList;
+class CUploadQueue;
+class CWebServer;
+class CxmuleDlg;
+
 
-#include "resource.h"
-#include "xmuleDlg.h"
-#include "KnownFileList.h"
-#include "Preferences.h"
-#include "sockets.h"
-#include "ServerList.h"
-#include "SharedFileList.h"
-#include "SearchList.h"
-#include "ListenSocket.h"
-#include "UploadQueue.h"
-#include "DownloadQueue.h"
-#include "ClientList.h"
-#include "ClientCredits.h"
-#include "FriendList.h"
-#include "ClientUDPSocket.h"
-#include "IPFilter.h"
-#include "WebServer.h"
 //#include <afxmt.h>
 
 //extern CxmuleApp theApp;
 #define theApp (*((CxmuleApp*)wxTheApp))
 #define G_BLEND(a,b) ( ((int)a*b)/100>255?255:((int)a*b)/100 ) 
 
-class CSearchList;
-class CUploadQueue;
-class CListenSocket;
-class CDownloadQueue;
-class CSharedFileList;
 
 class CxmuleApp : public wxApp {
 public:
@@ -61,22 +65,20 @@ public:
 	virtual		~CxmuleApp();
 	int			OnExit();
 	void			OnFatalException();
-
-	CxmuleDlg*		xmuledlg;
-	CClientList*		clientlist;
-	CKnownFileList*		knownfiles;
-	CPreferences*		glob_prefs;
-	CServerConnect*		serverconnect;
-	CServerList*		serverlist;	
-	CSharedFileList*	sharedfiles;
-	CSearchList*		searchlist;
-	CListenSocket*		listensocket;
-	CUploadQueue*		uploadqueue;
-	CDownloadQueue*		downloadqueue;
-	CClientCreditsList*	clientcredits;
-	CClientUDPSocket*	clientudp;
-	CFriendList*		friendlist;
-	CWebServer*		webserver;
+	CxmuleDlg *xmuledlg;
+	CClientList *clientlist;
+	CKnownFileList *knownfiles;
+	CPreferences *glob_prefs;
+	CServerConnect *serverconnect;
+	CServerList *serverlist;	
+	CSharedFileList *sharedfiles;
+	CListenSocket *listensocket;
+	CUploadQueue *uploadqueue;
+	CDownloadQueue *downloadqueue;
+	CClientCreditsList *clientcredits;
+	CClientUDPSocket *clientudp;
+	CFriendList *friendlist;
+	CWebServer *webserver;
 	//virtual BOOL		InitInstance();
 	virtual bool 		OnInit();
 	wxString*		pendinglink;
@@ -113,7 +115,7 @@ protected:
 };
 
 // helper
-wxColour 			GetColour(wxSystemColour what);
+wxColour GetColour(wxSystemColour what);
 
 
 #endif
